<?php
require get_template_directory() . '/inc/helpers.php';
require get_template_directory() . '/inc/sanitization.php';
require get_template_directory() . '/inc/functions.php';
require get_template_directory() . '/inc/helpers-post-meta.php';
require get_template_directory() . '/inc/customizer.php';
require get_template_directory() . '/inc/customizer-styles.php';

require get_template_directory() . '/inc/custom-fields-post.php';
require get_template_directory() . '/inc/custom-fields-page.php';
require get_template_directory() . '/inc/custom-fields-service.php';
require get_template_directory() . '/inc/custom-fields-project.php';
require get_template_directory() . '/inc/custom-fields-team.php';
require get_template_directory() . '/inc/custom-fields-diy.php';
require get_template_directory() . '/inc/custom-fields-faq.php';

/**
 * Common theme features.
 */
require_once get_theme_file_path( '/common/common.php' );

/**
 * Elementor related code.
 */
if ( defined( 'ELEMENTOR_VERSION' ) && version_compare( PHP_VERSION, '5.4', '>=' ) ) {
	require_once get_theme_file_path( 'inc/elementor/inc/elementor-helper.php' );
	require_once get_theme_file_path( 'inc/elementor/inc/struct-element-common-functions.php' );
	require_once get_theme_file_path( 'inc/elementor/elementor.php' );
}

add_action( 'after_setup_theme', 'struct_content_width', 0 );
function struct_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'struct_content_width', 848 );
}

add_action( 'after_setup_theme', 'struct_setup' );
if( !function_exists( 'struct_setup' ) ) :
function struct_setup() {

	if ( ! defined( 'STRUCT_NAME' ) ) {
		define( 'STRUCT_NAME', 'struct' );
	}
	if ( ! defined( 'CI_WHITELABEL' ) ) {
		// Set the following to true, if you want to remove any user-facing CSSIgniter traces.
		define( 'CI_WHITELABEL', false );
	}

	load_theme_textdomain( 'struct', get_template_directory() . '/languages' );

	/*
	 * Theme supports.
	 */
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );
	add_theme_support( 'custom-background' );

	add_theme_support( 'custom-logo', array(
		'height'      => 80,
		'width'       => 260,
		'flex-height' => true,
	) );

	add_theme_support( 'custom-header', array(
		'header-text' => false,
		'height'      => 96,
		'flex-height' => false,
		'width'       => 1920,
		'flex-width'  => false,
	) );

	/*
	 * Image sizes.
	 */
	set_post_thumbnail_size( 555, 350, true );
	add_image_size( 'struct_featured', 848, 450, true );
	add_image_size( 'struct_fullwidth', 1140, 450, true );
	add_image_size( 'struct_custom_content', 720, 430, true );
	add_image_size( 'struct_slide', 1920, 900, true );
	add_image_size( 'struct_client', 0, 80, false );


	/*
	 * Navigation menus.
	 */
	register_nav_menus( array(
		'main_menu' => esc_html__( 'Main Menu', 'struct' ),
	) );


	/*
	 * Default hooks
	 */
	// Prints the inline JS scripts that are registered for printing, and removes them from the queue.
	add_action( 'admin_footer', 'struct_print_inline_js' );
	add_action( 'wp_footer', 'struct_print_inline_js' );

	// Handle the dismissible sample content notice.
	add_action( 'admin_notices', 'struct_admin_notice_sample_content' );
	add_action( 'wp_ajax_struct_dismiss_sample_content', 'struct_ajax_dismiss_sample_content' );

	// Wraps post counts in span.ci-count
	// Needed for the default widgets, however more appropriate filters don't exist.
	add_filter( 'get_archives_link', 'struct_wrap_archive_widget_post_counts_in_span', 10, 2 );
	add_filter( 'wp_list_categories', 'struct_wrap_category_widget_post_counts_in_span', 10, 2 );
}
endif;

add_action( 'wp_enqueue_scripts', 'struct_enqueue_scripts' );
function struct_enqueue_scripts() {

	/*
	 * Styles
	 */
	$theme = wp_get_theme();

	wp_register_style( 'struct-base', get_template_directory_uri() . '/css/base.css', array(), $theme->get( 'Version' ) );
	wp_register_style( 'flexslider', get_template_directory_uri() . '/css/flexslider.css', array(), '2.5.0' );
	wp_register_style( 'mmenu', get_template_directory_uri() . '/css/mmenu.css', array(), '5.5.3' );
	wp_register_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.css', array(), '4.7.0' );
	wp_register_style( 'magnific-popup', get_template_directory_uri() . '/css/magnific.css', array(), '1.0.0' );

	wp_register_style( 'struct-dependencies', false, array(
		'struct-base',
		'struct-common',
		'flexslider',
		'mmenu',
		'font-awesome',
		'magnific-popup',
	), $theme->get( 'Version' ) );

	$main_dependencies = array(
		'struct-dependencies',
	);

	if ( is_child_theme() ) {
		wp_register_style( 'struct-style-parent', get_template_directory_uri() . '/style.css', $main_dependencies, $theme->get( 'Version' ) );
	}

	wp_register_style( 'struct-style', get_stylesheet_uri(), $main_dependencies, $theme->get( 'Version' ) );

	/*
	 * Scripts
	 */
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	wp_register_script( 'superfish', get_template_directory_uri() . '/js/superfish.js', array( 'jquery' ), '1.7.5', true );
	wp_register_script( 'mmenu', get_template_directory_uri() . '/js/jquery.mmenu.min.all.js', array( 'jquery' ), '5.5.3', true );
	wp_register_script( 'flexslider', get_template_directory_uri() . '/js/jquery.flexslider.js', array( 'jquery' ), '2.5.0', true );
	wp_register_script( 'fitVids', get_template_directory_uri() . '/js/jquery.fitvids.js', array( 'jquery' ), '1.1', true );
	wp_register_script( 'magnific-popup', get_template_directory_uri() . '/js/jquery.magnific-popup.js', array( 'jquery' ), '1.0.0', true );
	wp_register_script( 'match-height', get_template_directory_uri() . '/js/jquery.matchHeight.js', array( 'jquery' ), '1.0.0', true );

	wp_register_script( 'struct-front-scripts', get_template_directory_uri() . '/js/scripts.js', array(
		'jquery',
		'superfish',
		'mmenu',
		'flexslider',
		'fitVids',
		'magnific-popup',
		'match-height',
	), $theme->get( 'Version' ), true );


	/*
	 * Enqueue
	 */
	// Load the user-selected google fonts, if any.
	struct_enqueue_google_fonts();

	if ( is_child_theme() ) {
		wp_enqueue_style( 'struct-style-parent' );
	}

	wp_enqueue_style( 'struct-style' );
	wp_add_inline_style( 'struct-style', struct_get_all_customizer_css() );

	wp_enqueue_script( 'struct-front-scripts' );

}

add_action( 'admin_enqueue_scripts', 'struct_admin_enqueue_scripts' );
function struct_admin_enqueue_scripts( $hook ) {
	$theme = wp_get_theme();

	/*
	 * Styles
	 */
	wp_register_style( 'struct-repeating-fields', get_template_directory_uri() . '/assets/repeating-fields/repeating-fields.css', array(), $theme->get( 'Version' ) );

	wp_register_style( 'struct-widgets', get_template_directory_uri() . '/css/admin/widgets.css', array(
		'wp-color-picker',
		'struct-repeating-fields',
		'struct-post-meta'
	), $theme->get( 'Version' ) );


	/*
	 * Scripts
	 */
	wp_register_script( 'struct-repeating-fields', get_template_directory_uri() . '/assets/repeating-fields/repeating-fields.js', array(
		'jquery',
		'jquery-ui-sortable'
	), $theme->get( 'Version' ), true );

	wp_register_script( 'struct-widgets', get_template_directory_uri() . '/js/admin/widgets.js', array(
		'jquery',
		'wp-color-picker',
		'struct-repeating-fields',
		'struct-post-meta',
	), $theme->get( 'Version' ), true );
	$params = array(
		'no_posts_found' => esc_html__( 'No posts found.', 'struct' ),
		'ajaxurl'        => admin_url( 'admin-ajax.php' ),
	);
	wp_localize_script( 'struct-widgets', 'ThemeWidget', $params );


	/*
	 * Enqueue
	 */
	if ( in_array( $hook, array( 'post.php', 'post-new.php' ) ) ) {
		wp_enqueue_media();
		wp_enqueue_style( 'struct-post-meta' );
		wp_enqueue_script( 'struct-post-meta' );

		wp_enqueue_style( 'struct-repeating-fields' );
		wp_enqueue_script( 'struct-repeating-fields' );
	}

	if ( in_array( $hook, array( 'widgets.php', 'customize.php' ) ) ) {
		wp_enqueue_media();
		wp_enqueue_style( 'struct-widgets' );
		wp_enqueue_script( 'struct-widgets' );
	}

}


add_action( 'widgets_init', 'struct_widgets_init' );
function struct_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html_x( 'Blog', 'widget area', 'struct' ),
		'id'            => 'blog',
		'description'   => esc_html__( 'This is the main sidebar.', 'struct' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Pages', 'widget area', 'struct' ),
		'id'            => 'page',
		'description'   => esc_html__( 'This sidebar appears on your static pages.', 'struct' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Services', 'widget area', 'struct' ),
		'id'            => 'service',
		'description'   => esc_html__( 'This sidebar appears on your Services pages.', 'struct' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Projects', 'widget area', 'struct' ),
		'id'            => 'project',
		'description'   => esc_html__( 'This sidebar appears on your Projects pages.', 'struct' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Team', 'widget area', 'struct' ),
		'id'            => 'team',
		'description'   => esc_html__( 'This sidebar appears on your Team pages.', 'struct' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'DIY', 'widget area', 'struct' ),
		'id'            => 'diy',
		'description'   => esc_html__( 'This sidebar appears on your DIY pages.', 'struct' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'FAQ', 'widget area', 'struct' ),
		'id'            => 'faq',
		'description'   => esc_html__( 'This sidebar appears on your FAQ pages.', 'struct' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Homepage', 'widget area', 'struct' ),
		'id'            => 'homepage',
		'description'   => esc_html__( 'This widget area appears on your Homepage templates.', 'struct' ),
		'before_widget' => '<section id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="section-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Footer #1', 'widget area', 'struct' ),
		'id'            => 'footer-1',
		'description'   => esc_html__( 'This is the first column of widgets on the footer.', 'struct' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Footer #2', 'widget area', 'struct' ),
		'id'            => 'footer-2',
		'description'   => esc_html__( 'This is the second column of widgets on the footer.', 'struct' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Footer #3', 'widget area', 'struct' ),
		'id'            => 'footer-3',
		'description'   => esc_html__( 'This is the third column of widgets on the footer.', 'struct' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Footer #4', 'widget area', 'struct' ),
		'id'            => 'footer-4',
		'description'   => esc_html__( 'This is the fourth column of widgets on the footer.', 'struct' ),
		'before_widget' => '<aside id="%1$s" class="widget group %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

}

add_action( 'widgets_init', 'struct_load_widgets' );
function struct_load_widgets() {
	require get_template_directory() . '/inc/widgets/slider.php';
	require get_template_directory() . '/inc/widgets/testimonials.php';
	require get_template_directory() . '/inc/widgets/clients.php';
	require get_template_directory() . '/inc/widgets/pricing-table.php';
	require get_template_directory() . '/inc/widgets/custom-content.php';
	require get_template_directory() . '/inc/widgets/latest-posts.php';
	require get_template_directory() . '/inc/widgets/post-type-items.php';
	require get_template_directory() . '/inc/widgets/video.php';

	require get_template_directory() . '/inc/widgets/socials.php';
	require get_template_directory() . '/inc/widgets/opening-hours.php';
	require get_template_directory() . '/inc/widgets/contact-info.php';
	require get_template_directory() . '/inc/widgets/technical-documentation.php';
	require get_template_directory() . '/inc/widgets/callout.php';
}

add_filter( 'excerpt_length', 'struct_excerpt_length' );
function struct_excerpt_length( $length ) {
	return get_theme_mod( 'excerpt_length', 55 );
}


add_filter( 'wp_page_menu', 'struct_wp_page_menu', 10, 2 );
function struct_wp_page_menu( $menu, $args ) {
	preg_match( '#^<div class="(.*?)">(?:.*?)</div>$#', $menu, $matches );
	$menu = preg_replace( '#^<div class=".*?">#', '', $menu, 1 );
	$menu = preg_replace( '#</div>$#', '', $menu, 1 );
	$menu = preg_replace( '#^<ul>#', '<ul class="' . esc_attr( $args['menu_class'] ) . '">', $menu, 1 );
	return $menu;
}


add_filter( 'the_content', 'struct_lightbox_rel', 12 );
add_filter( 'get_comment_text', 'struct_lightbox_rel' );
if ( ! function_exists( 'struct_lightbox_rel' ) ):
function struct_lightbox_rel( $content ) {
	global $post;
	$pattern     = "/<a(.*?)href=('|\")([^>]*).(bmp|gif|jpeg|jpg|png)('|\")(.*?)>(.*?)<\/a>/i";
	$replacement = '<a$1href=$2$3.$4$5 data-lightbox="gal[' . $post->ID . ']"$6>$7</a>';
	$content     = preg_replace( $pattern, $replacement, $content );

	return $content;
}
endif;


if ( ! function_exists( 'struct_get_columns_classes' ) ):
function struct_get_columns_classes( $columns, $fullwidth = true ) {
	switch ( intval( $columns ) ) {
		case 3:
			$classes = 'col-lg-4 col-md-6 col-xs-12';
			if ( ! $fullwidth ) {
				$classes = 'col-xl-4 col-md-6 col-xs-12';
			}
			break;
		case 4:
			$classes = 'col-lg-3 col-md-6 col-xs-12';
			break;
		case 2:
		default:
			$classes = 'col-md-6 col-xs-12';
			break;
	}

	return apply_filters( 'struct_get_columns_classes', $classes, $columns, $fullwidth );
}
endif;

if ( ! function_exists( 'struct_best_number_of_columns' ) ):
function struct_best_number_of_columns( $count ) {
	$columns = apply_filters( 'struct_best_number_of_columns_default', 3 );

	if ( $count >= 1 && $count <= 4 ) {
		$columns = intval( $count );
	} elseif ( $count > 4 ) {
		if ( ( $count % 4 ) == 0 ) {
			$columns = 4;
		} elseif ( ( $count % 3 ) == 0 ) {
			$columns = 3;
		} elseif ( ( $count % 2 ) == 0 ) {
			$columns = 2;
		}
	}

	return apply_filters( 'struct_best_number_of_columns', $columns, $count );
}
endif;

if ( ! function_exists( 'struct_get_listing_layouts' ) ):
function struct_get_listing_layouts() {
	// The array keys MUST be comprised of two parts, separated by a dash.
	// First is the number of columns, followed by sidebar or fullwidth.
	// These are broken down within the templates to display things appropriately.
	return apply_filters( 'struct_listing_layouts', array(
		'2-sidebar'   => esc_html__( '2 Columns with Sidebar', 'struct' ),
		'3-sidebar'   => esc_html__( '3 Columns with Sidebar', 'struct' ),
		'2-fullwidth' => esc_html__( '2 Columns Full width', 'struct' ),
		'3-fullwidth' => esc_html__( '3 Columns Full width', 'struct' ),
		'4-fullwidth' => esc_html__( '4 Columns Full width', 'struct' ),
	) );
}
endif;

if ( ! function_exists( 'struct_get_listing_item_layouts' ) ):
function struct_get_listing_item_layouts( $post_type ) {
	$layouts = array();

	$defaults = array(
		'nothumb-nobutton'     => esc_html_x( 'Title - Text', 'item layout', 'struct' ),
		'nothumb'              => esc_html_x( 'Title - Text - Button', 'item layout', 'struct' ),
		'thumb-nobutton'       => esc_html_x( 'Image - Title - Text', 'item layout', 'struct' ),
		'thumb-notext'         => esc_html_x( 'Image - Title - Date - Button', 'item layout', 'struct' ),
		'thumb'                => esc_html_x( 'Image - Title - Date - Text - Button', 'item layout', 'struct' ),
		'icon-left'            => esc_html_x( 'Icon Left - Button', 'item layout', 'struct' ),
		'icon-left-nobutton'   => esc_html_x( 'Icon Left', 'item layout', 'struct' ),
		'icon-center'          => esc_html_x( 'Icon Centered - Button', 'item layout', 'struct' ),
		'icon-center-nobutton' => esc_html_x( 'Icon Centered', 'item layout', 'struct' ),
		'social'               => esc_html_x( 'Social', 'item layout', 'struct' ),
	);

	switch ( $post_type ) {
		case 'struct_team':
			$layouts['social'] = $defaults['social'];
			break;
		case 'struct_service':
			$layouts['icon-left']            = $defaults['icon-left'];
			$layouts['icon-left-nobutton']   = $defaults['icon-left-nobutton'];
			$layouts['icon-center']          = $defaults['icon-center'];
			$layouts['icon-center-nobutton'] = $defaults['icon-center-nobutton'];
			$layouts['thumb-nobutton']       = $defaults['thumb-nobutton'];
			break;
		case 'post':
		case 'page':
		case 'struct_diy':
		case 'struct_project':
		default:
			$layouts['nothumb-nobutton'] = $defaults['nothumb-nobutton'];
			$layouts['nothumb']          = $defaults['nothumb'];
			$layouts['thumb-nobutton']   = $defaults['thumb-nobutton'];
			$layouts['thumb-notext']     = $defaults['thumb-notext'];
			$layouts['thumb']            = $defaults['thumb'];
	}

	return apply_filters( 'struct_listing_item_layouts', $layouts, $post_type, $defaults );
}
endif;

if ( ! function_exists( 'struct_get_social_networks') ):
function struct_get_social_networks() {
	return apply_filters( 'struct_social_networks', array(
		array(
			'name'  => 'facebook',
			'label' => esc_html__( 'Facebook', 'struct' ),
			'icon'  => 'fa-facebook',
		),
		array(
			'name'  => 'twitter',
			'label' => esc_html__( 'Twitter', 'struct' ),
			'icon'  => 'fa-twitter',
		),
		array(
			'name'  => 'pinterest',
			'label' => esc_html__( 'Pinterest', 'struct' ),
			'icon'  => 'fa-pinterest',
		),
		array(
			'name'  => 'instagram',
			'label' => esc_html__( 'Instagram', 'struct' ),
			'icon'  => 'fa-instagram',
		),
		array(
			'name'  => 'linkedin',
			'label' => esc_html__( 'LinkedIn', 'struct' ),
			'icon'  => 'fa-linkedin',
		),
		array(
			'name'  => 'tumblr',
			'label' => esc_html__( 'Tumblr', 'struct' ),
			'icon'  => 'fa-tumblr',
		),
		array(
			'name'  => 'flickr',
			'label' => esc_html__( 'Flickr', 'struct' ),
			'icon'  => 'fa-flickr',
		),
		array(
			'name'  => 'bloglovin',
			'label' => esc_html__( 'Bloglovin', 'struct' ),
			'icon'  => 'fa-heart',
		),
		array(
			'name'  => 'youtube',
			'label' => esc_html__( 'YouTube', 'struct' ),
			'icon'  => 'fa-youtube',
		),
		array(
			'name'  => 'vimeo',
			'label' => esc_html__( 'Vimeo', 'struct' ),
			'icon'  => 'fa-vimeo',
		),
		array(
			'name'  => 'dribbble',
			'label' => esc_html__( 'Dribbble', 'struct' ),
			'icon'  => 'fa-dribbble',
		),
		array(
			'name'  => 'wordpress',
			'label' => esc_html__( 'WordPress', 'struct' ),
			'icon'  => 'fa-wordpress',
		),
		array(
			'name'  => '500px',
			'label' => esc_html__( '500px', 'struct' ),
			'icon'  => 'fa-500px',
		),
		array(
			'name'  => 'soundcloud',
			'label' => esc_html__( 'Soundcloud', 'struct' ),
			'icon'  => 'fa-soundcloud',
		),
		array(
			'name'  => 'spotify',
			'label' => esc_html__( 'Spotify', 'struct' ),
			'icon'  => 'fa-spotify',
		),
		array(
			'name'  => 'vine',
			'label' => esc_html__( 'Vine', 'struct' ),
			'icon'  => 'fa-vine',
		),
		array(
			'name'  => 'tripadvisor',
			'label' => esc_html__( 'Trip Advisor', 'struct' ),
			'icon'  => 'fa-tripadvisor',
		),
		array(
			'name'  => 'telegram',
			'label' => esc_html__( 'Telegram', 'struct' ),
			'icon'  => 'fa-telegram',
		),
	) );
}
endif;


if ( ! function_exists( 'struct_get_fullwidth_sidebars' ) ):
function struct_get_fullwidth_sidebars() {
	return apply_filters( 'struct_get_fullwidth_sidebars', array(
		'homepage',
	) );
}
endif;


add_action( 'wp_head', 'struct_print_google_analytics_tracking' );
if ( ! function_exists( 'struct_print_google_analytics_tracking' ) ):
function struct_print_google_analytics_tracking() {
	if ( is_admin() || ! get_theme_mod( 'google_anaytics_tracking_id' ) ) {
		return;
	}
	?>
	<script>
		(function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
		(i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
		m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
		})(window,document,'script','//www.google-analytics.com/analytics.js','ga');

		ga('create', '<?php echo get_theme_mod( 'google_anaytics_tracking_id' ); ?>', 'auto');
		ga('send', 'pageview');
	</script>
	<?php
}
endif;


add_filter( 'struct_pagination_default_args', 'struct_pagination_default_args' );
if ( ! function_exists( 'struct_pagination_default_args' ) ):
function struct_pagination_default_args( $args ) {
	$args['container_id']    = '';
	$args['container_class'] = 'paging';

	return $args;
}
endif;


if ( ! function_exists( 'struct_homepage_has_transparent_header' ) ):
function struct_homepage_has_transparent_header() {
	$unconditional_widgets = apply_filters( 'struct_homepage_transparent_header_widgets_unconditional', array(
		'ci-slideshow',
	) );
	$conditional_widgets = apply_filters( 'struct_homepage_transparent_header_widgets_conditional', array(
		'ci-clients',
		'ci-custom-content',
		'ci-latest-posts',
		'ci-post-type-items',
		'ci-pricing-table',
		'ci-testimonials',
		'ci-video',
	) );

	$sw = wp_get_sidebars_widgets();
	if ( empty( $sw['homepage'] ) ) {
		return false;
	}

	$widgets = $sw['homepage'];
	$first   = reset( $widgets );

	if ( ! preg_match( '/(.*)-(\d+)/', $first, $matches ) ) {
		return false;
	}

	$widget_name = $matches[1];
	$widget_id   = intval( $matches[2] );

	if ( in_array( $widget_name, $unconditional_widgets ) ) {
		return true;
	}

	$options = get_option( "widget_{$widget_name}" );

	if ( ! empty( $options[ $widget_id ] ) ) {
		if ( ! empty( $options[ $widget_id ]['background_color'] ) || ! empty( $options[ $widget_id ]['background_image'] ) ) {
			return true;
		}

	}

	return false;
}
endif;


if ( ! function_exists( 'struct_get_repeat_choices' ) ):
function struct_get_repeat_choices() {
	return array(
		'no-repeat' => esc_html_x( 'No Repeat', 'background repeat', 'struct' ),
		'repeat'    => esc_html_x( 'Repeat', 'background repeat', 'struct' ),
		'repeat-x'  => esc_html_x( 'Repeat Horizontally', 'background repeat', 'struct' ),
		'repeat-y'  => esc_html_x( 'Repeat Vertically', 'background repeat', 'struct' ),
	);
}
endif;

if ( ! function_exists( 'struct_sanitize_repeat_choices' ) ):
function struct_sanitize_repeat_choices( $value ) {
	$choices = struct_get_repeat_choices();
	if ( array_key_exists( $value, $choices ) ) {
		return $value;
	}

	return 'no-repeat';
}
endif;

if ( ! function_exists( 'struct_get_bg_position_x_choices' ) ):
function struct_get_bg_position_x_choices() {
	return array(
		'left'   => esc_html_x( 'Left', 'horizontal position', 'struct' ),
		'center' => esc_html_x( 'Center', 'horizontal position', 'struct' ),
		'right'  => esc_html_x( 'Right', 'horizontal position', 'struct' ),
	);
}
endif;

if ( ! function_exists( 'struct_sanitize_bg_position_x' ) ):
function struct_sanitize_bg_position_x( $value ) {
	$choices = struct_get_bg_position_x_choices();
	if ( array_key_exists( $value, $choices ) ) {
		return $value;
	}

	return 'left';
}
endif;



if ( ! function_exists( 'struct_allowed_subtitle_tags' ) ):
function struct_allowed_subtitle_tags() {
	return apply_filters( 'struct_allowed_subtitle_tags', struct_get_allowed_tags( 'guide' ) );
}
endif;

if ( ! function_exists( 'struct_sanitize_footer_text' ) ):
function struct_sanitize_footer_text( $text ) {
	return wp_kses( $text, struct_get_allowed_tags( 'guide' ) );
}
endif;


if ( ! function_exists( 'struct_get_default_footer_text' ) ):
function struct_get_default_footer_text( $position = '' ) {
	if ( ! defined( 'CI_WHITELABEL' ) || ! CI_WHITELABEL ) {
		if ( $position == 'right' ) {
			$text = sprintf( __( 'Handcrafted by <a href="%s">CSSIgniter.com</a>', 'struct' ),
				esc_url( 'http://www.cssigniter.com/ignite/' )
			);
		} else {
			$text = sprintf( __( '<a href="%s">Struct</a> &ndash; Business Theme for WordPress', 'struct' ),
				esc_url( 'http://www.cssigniter.com/ignite/themes/struct/' )
			);
		}
	} else {
		if ( $position == 'right' ) {
			$text = sprintf( __( 'Powered by <a href="%s">WordPress</a>', 'struct' ),
				esc_url( 'https://wordpress.org/' )
			);
		} else {
			$text = sprintf( '<a href="%1$s">%2$s</a>',
				esc_url( home_url( '/' ) ),
				get_bloginfo( 'name' )
			);
		}
	}

	return $text;
}
endif;

if ( ! defined( 'STRUCT_WHITELABEL' ) || false === (bool) STRUCT_WHITELABEL ) {
	add_filter( 'pt-ocdi/import_files', 'struct_ocdi_import_files' );
	add_action( 'pt-ocdi/after_import', 'struct_ocdi_after_import_setup' );
}

function struct_ocdi_import_files( $files ) {
	if ( ! defined( 'STRUCT_NAME' ) ) {
		define( 'STRUCT_NAME', 'struct' );
	}

	$demo_dir_url = untrailingslashit( apply_filters( 'struct_ocdi_demo_dir_url', 'https://www.cssigniter.com/sample_content/' . STRUCT_NAME ) );

	// When having more that one predefined imports, set a preview image, preview URL, and categories for isotope-style filtering.
	$new_files = array(
		array(
			'import_file_name'           => esc_html__( 'Demo Import', 'struct' ),
			'import_file_url'            => $demo_dir_url . '/content.xml',
			'import_widget_file_url'     => $demo_dir_url . '/widgets.wie',
			'import_customizer_file_url' => $demo_dir_url . '/customizer.dat',
		),
	);

	return array_merge( $files, $new_files );
}

function struct_ocdi_after_import_setup() {
	// Set up nav menus.
	$main_menu = get_term_by( 'name', 'Main', 'nav_menu' );

	set_theme_mod( 'nav_menu_locations', array(
		'main_menu' => $main_menu->term_id,
	) );

	// Set up home and blog pages.
	$front_page_id = get_page_by_title( 'Home' );
	$blog_page_id  = get_page_by_title( 'Blog' );

	update_option( 'show_on_front', 'page' );
	update_option( 'page_on_front', $front_page_id->ID );
	update_option( 'page_for_posts', $blog_page_id->ID );

	// Try to force a term recount.
	// wp_defer_term_counting( false ) doesn't work properly as there are post imported from different AJAX requests.
	$taxonomies = get_taxonomies( array(), 'names' );
	foreach ( $taxonomies as $taxonomy ) {
		$terms             = get_terms( $taxonomy, array( 'hide_empty' => false ) );
		$term_taxonomy_ids = wp_list_pluck( $terms, 'term_taxonomy_id' );

		wp_update_term_count( $term_taxonomy_ids, $taxonomy );
	}
}

add_action( 'init', 'struct_migrate_custom_css_to_customizer' );
function struct_migrate_custom_css_to_customizer() {
	if ( ! is_admin() || wp_doing_ajax() || ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) ) {
		return;
	}

	$migrated = get_theme_mod( 'custom_css_migrated', false );

	if ( $migrated || ! function_exists( 'wp_update_custom_css_post' ) ) {
		return;
	}

	// Migrate any existing theme CSS to the core option added in WordPress 4.7.
	$css = get_theme_mod( 'custom_css', '' );
	if ( $css ) {
		// Preserve any CSS already added to the core option.
		$core_css = wp_get_custom_css();

		$return = wp_update_custom_css_post( $core_css .
			PHP_EOL . PHP_EOL .
			"/* Migrated CSS from the theme's old custom CSS setting. */" .
			PHP_EOL .
			html_entity_decode( $css )
		);

		if ( ! is_wp_error( $return ) ) {
			// Remove the old option, so that the CSS is stored in only one place moving forward.
			set_theme_mod( 'custom_css', '' );
			set_theme_mod( 'custom_css_migrated', true );
		}
	}
}

function struct_customizer_defaults( $setting = false ) {
	$theme = wp_get_theme();

	// phpcs:disable WordPress.Arrays.MultipleStatementAlignment.DoubleArrowNotAligned
	$defaults = apply_filters(
		'struct_customizer_defaults',
		array(
			'global_typo_disable_google_fonts' => 0,
			'global_typo_body' => struct_typography_control_defaults_empty_breakpoints(
				array(
					'desktop' => array(
						'family'     => 'Rubik',
						'variant'    => 'regular',
						'size'       => 14,
						'lineHeight' => 1.625,
						'transform'  => 'none',
						'spacing'    => '',
						'is_gfont'   => true,
					),
				)
			),
			'global_typo_h1' => struct_typography_control_defaults_empty_breakpoints(
				array(
					'desktop' => array(
						'family'     => 'Rubik',
						'variant'    => 'regular',
						'size'       => 36,
						'lineHeight' => 1.2,
						'transform'  => 'none',
						'spacing'    => '',
						'is_gfont'   => true,
					),
				)
			),
			'global_typo_h2' => struct_typography_control_defaults_empty_breakpoints(
				array(
					'desktop' => array(
						'family'     => 'Rubik',
						'variant'    => 'regular',
						'size'       => 30,
						'lineHeight' => 1.2,
						'transform'  => 'none',
						'spacing'    => '',
						'is_gfont'   => true,
					),
				)
			),
			'global_typo_h3' => struct_typography_control_defaults_empty_breakpoints(
				array(
					'desktop' => array(
						'family'     => 'Rubik',
						'variant'    => 'regular',
						'size'       => 24,
						'lineHeight' => 1.2,
						'transform'  => 'none',
						'spacing'    => '',
						'is_gfont'   => true,
					),
				)
			),
			'global_typo_h4' => struct_typography_control_defaults_empty_breakpoints(
				array(
					'desktop' => array(
						'family'     => 'Rubik',
						'variant'    => 'regular',
						'size'       => 20,
						'lineHeight' => 1.2,
						'transform'  => 'none',
						'spacing'    => '',
						'is_gfont'   => true,
					),
				)
			),
			'global_typo_h5' => struct_typography_control_defaults_empty_breakpoints(
				array(
					'desktop' => array(
						'family'     => 'Rubik',
						'variant'    => 'regular',
						'size'       => 17,
						'lineHeight' => 1.2,
						'transform'  => 'none',
						'spacing'    => '',
						'is_gfont'   => true,
					),
				)
			),
			'global_typo_h6' => struct_typography_control_defaults_empty_breakpoints(
				array(
					'desktop' => array(
						'family'     => 'Rubik',
						'variant'    => 'regular',
						'size'       => 14,
						'lineHeight' => 1.2,
						'transform'  => 'none',
						'spacing'    => '',
						'is_gfont'   => true,
					),
				)
			),
			'global_typo_form_labels' => struct_typography_control_defaults_empty_breakpoints(
				array(
					'desktop' => array(
						'family'     => 'Rubik',
						'variant'    => '500',
						'size'       => 14,
						'lineHeight' => 1.625,
						'transform'  => 'none',
						'spacing'    => '',
						'is_gfont'   => true,
					),
				)
			),
			'global_typo_form_text' => struct_typography_control_defaults_empty_breakpoints(
				array(
					'desktop' => array(
						'family'     => 'Rubik',
						'variant'    => 'regular',
						'size'       => 14,
						'lineHeight' => 1.625,
						'transform'  => 'none',
						'spacing'    => '',
						'is_gfont'   => true,
					),
				)
			),
			'global_typo_buttons' => struct_typography_control_defaults_empty_breakpoints(
				array(
					'desktop' => array(
						'family'     => 'Rubik',
						'variant'    => '700',
						'size'       => 13,
						'lineHeight' => 1.2,
						'transform'  => 'uppercase',
						'spacing'    => '',
						'is_gfont'   => true,
					),
				)
			),
			'global_typo_widget_titles' => struct_typography_control_defaults_empty_breakpoints(
				array(
					'desktop' => array(
						'family'     => 'Rubik',
						'variant'    => 'regular',
						'size'       => 24,
						'lineHeight' => 1.2,
						'transform'  => 'none',
						'spacing'    => '',
						'is_gfont'   => true,
					),
				)
			),
			'global_typo_widget_text' => struct_typography_control_defaults_empty_breakpoints(
				array(
					'desktop' => array(
						'family'     => 'Rubik',
						'variant'    => 'regular',
						'size'       => 14,
						'lineHeight' => 1.625,
						'transform'  => 'none',
						'spacing'    => '',
						'is_gfont'   => true,
					),
				)
			),
		)
	);
	// phpcs:enable

	if ( ! empty( $setting ) && array_key_exists( $setting, $defaults ) ) {
		return apply_filters( 'struct_customizer_default', $defaults[ $setting ], $setting );
	}

	return $defaults;
}

/**
 * Data upgrade.
 */
require_once get_theme_file_path( '/inc/upgrade.php' );

/**
 * Outputs a preconnect link that helps performance of Google Fonts.
 * Hooked conditionally on 'wp_head'.
 */
function struct_head_preconnect_google_fonts() {
	?><link rel="preconnect" href="https://fonts.gstatic.com/" crossorigin><?php
}

/**
 * Fonts list.
 */
require_once get_theme_file_path( '/inc/class-fonts-list.php' );
