<?php
	add_action( 'init', 'struct_create_diy' );

	if ( ! function_exists( 'struct_create_diy' ) ):
	function struct_create_diy() {
		$labels = array(
			'name'               => esc_html_x( 'DIY Projects', 'post type general name', 'struct' ),
			'singular_name'      => esc_html_x( 'DIY Project', 'post type singular name', 'struct' ),
			'menu_name'          => esc_html_x( 'DIY Projects', 'admin menu', 'struct' ),
			'name_admin_bar'     => esc_html_x( 'DIY Project', 'add new on admin bar', 'struct' ),
			'add_new'            => esc_html__( 'Add New', 'struct' ),
			'add_new_item'       => esc_html__( 'Add New DIY Project', 'struct' ),
			'edit_item'          => esc_html__( 'Edit DIY Project', 'struct' ),
			'new_item'           => esc_html__( 'New DIY Project', 'struct' ),
			'view_item'          => esc_html__( 'View DIY Project', 'struct' ),
			'search_items'       => esc_html__( 'Search DIY Projects', 'struct' ),
			'not_found'          => esc_html__( 'No DIY Projects found', 'struct' ),
			'not_found_in_trash' => esc_html__( 'No DIY Projects found in the trash', 'struct' ),
			'parent_item_colon'  => esc_html__( 'Parent DIY Project:', 'struct' )
		);

		$args = array(
			'labels'          => $labels,
			'singular_label'  => esc_html_x( 'DIY Project', 'post type singular name', 'struct' ),
			'public'          => true,
			'show_ui'         => true,
			'capability_type' => 'post',
			'hierarchical'    => false,
			'has_archive'     => _x( 'diy-archive', 'post type archive slug', 'struct' ),
			'rewrite'         => array( 'slug' => esc_html_x( 'diy', 'post type slug', 'struct' ) ),
			'menu_position'   => 5,
			'supports'        => array( 'title', 'editor', 'thumbnail', 'author', 'excerpt', 'comments', 'trackbacks', 'revisions' ),
			'menu_icon'       => 'dashicons-hammer'
		);

		register_post_type( 'struct_diy', $args );

		$labels = array(
			'name'              => esc_html_x( 'DIY Project Categories', 'taxonomy general name', 'struct' ),
			'singular_name'     => esc_html_x( 'DIY Project Category', 'taxonomy singular name', 'struct' ),
			'search_items'      => esc_html__( 'Search DIY Project Categories', 'struct' ),
			'all_items'         => esc_html__( 'All DIY Project Categories', 'struct' ),
			'parent_item'       => esc_html__( 'Parent DIY Project Category', 'struct' ),
			'parent_item_colon' => esc_html__( 'Parent DIY Project Category:', 'struct' ),
			'edit_item'         => esc_html__( 'Edit DIY Project Category', 'struct' ),
			'update_item'       => esc_html__( 'Update DIY Project Category', 'struct' ),
			'add_new_item'      => esc_html__( 'Add New DIY Project Category', 'struct' ),
			'new_item_name'     => esc_html__( 'New DIY Project Category Name', 'struct' ),
			'menu_name'         => esc_html__( 'Categories', 'struct' ),
			'view_item'         => esc_html__( 'View DIY Project Category', 'struct' ),
			'popular_items'     => esc_html__( 'Popular DIY Project Categories', 'struct' ),
		);
		register_taxonomy( 'struct_diy_category', array( 'struct_diy' ), array(
			'labels'            => $labels,
			'hierarchical'      => true,
			'show_admin_column' => true,
			'rewrite'           => array( 'slug' => esc_html_x( 'diy-category', 'taxonomy slug', 'struct' ) ),
		) );

	}
	endif;

	add_action( 'admin_init', 'struct_cpt_diy_add_metaboxes' );
	add_action( 'save_post', 'struct_cpt_diy_update_meta' );

	if ( ! function_exists( 'struct_cpt_diy_add_metaboxes' ) ):
	function struct_cpt_diy_add_metaboxes() {
		add_meta_box( 'struct-diy-box', esc_html__( 'DIY Project Options', 'struct' ), 'struct_add_cpt_diy_meta_box', 'struct_diy', 'normal', 'high' );
	}
	endif;

	if ( ! function_exists( 'struct_cpt_diy_update_meta' ) ):
	function struct_cpt_diy_update_meta( $post_id ) {

		if ( ! struct_can_save_meta( 'struct_diy' ) ) {
			return;
		}

		update_post_meta( $post_id, 'struct_hide_featured', struct_sanitize_checkbox_ref( $_POST['struct_hide_featured'] ) );
	}
	endif;

	if ( ! function_exists( 'struct_add_cpt_diy_meta_box' ) ):
	function struct_add_cpt_diy_meta_box( $object, $box ) {
		struct_prepare_metabox( 'struct_diy' );

		?><div class="ci-cf-wrap"><?php
			struct_metabox_open_tab( '' );
				struct_metabox_checkbox( 'struct_hide_featured', 1, esc_html__( "Don't show the featured image when viewing this individual page.", 'struct' ) );
			struct_metabox_close_tab();
		?></div><?php
	}
	endif;
