<?php
	add_action( 'admin_init', 'struct_cpt_page_add_metaboxes' );
	add_action( 'save_post', 'struct_cpt_page_update_meta' );

	if ( ! function_exists( 'struct_cpt_page_add_metaboxes' ) ):
	function struct_cpt_page_add_metaboxes() {
		add_meta_box( 'struct-page-box', esc_html__( 'Page Options', 'struct' ), 'struct_add_cpt_page_meta_box', 'page', 'normal', 'high' );

		add_meta_box( 'struct-tpl-project-listing-meta', esc_html__( 'Project Listing Options', 'struct' ), 'struct_add_page_project_listing_meta_box', 'page', 'normal', 'high' );
		add_meta_box( 'struct-tpl-service-listing-meta', esc_html__( 'Service Listing Options', 'struct' ), 'struct_add_page_service_listing_meta_box', 'page', 'normal', 'high' );
		add_meta_box( 'struct-tpl-team-listing-meta', esc_html__( 'Team Listing Options', 'struct' ), 'struct_add_page_team_listing_meta_box', 'page', 'normal', 'high' );
		add_meta_box( 'struct-tpl-faq-listing-meta', esc_html__( 'FAQ Listing Options', 'struct' ), 'struct_add_page_faq_listing_meta_box', 'page', 'normal', 'high' );
		add_meta_box( 'struct-tpl-diy-listing-meta', esc_html__( 'DIY Listing Options', 'struct' ), 'struct_add_page_diy_listing_meta_box', 'page', 'normal', 'high' );
	}
	endif;

	if ( ! function_exists( 'struct_cpt_page_update_meta' ) ):
	function struct_cpt_page_update_meta( $post_id ) {

		if ( ! struct_can_save_meta( 'page' ) ) {
			return;
		}

		update_post_meta( $post_id, 'struct_hide_featured', struct_sanitize_checkbox_ref( $_POST['struct_hide_featured'] ) );
		update_post_meta( $post_id, 'struct_subtitle', sanitize_text_field( $_POST['struct_subtitle'] ) );

		update_post_meta( $post_id, 'struct_project_listing_base_category', intval( $_POST['struct_project_listing_base_category'] ) );
		update_post_meta( $post_id, 'struct_project_listing_layout', array_key_exists( $_POST['struct_project_listing_layout'], struct_get_listing_layouts() ) ? $_POST['struct_project_listing_layout'] : '2-sidebar' );
		update_post_meta( $post_id, 'struct_project_listing_item_layout', array_key_exists( $_POST['struct_project_listing_item_layout'], struct_get_listing_item_layouts( 'struct_project' ) ) ? $_POST['struct_project_listing_item_layout'] : 'thumb' );
		update_post_meta( $post_id, 'struct_project_listing_posts_per_page', intval( $_POST['struct_project_listing_posts_per_page'] ) );

		update_post_meta( $post_id, 'struct_service_listing_base_category', intval( $_POST['struct_service_listing_base_category'] ) );
		update_post_meta( $post_id, 'struct_service_listing_layout', array_key_exists( $_POST['struct_service_listing_layout'], struct_get_listing_layouts() ) ? $_POST['struct_service_listing_layout'] : '2-sidebar' );
		update_post_meta( $post_id, 'struct_service_listing_item_layout', array_key_exists( $_POST['struct_service_listing_item_layout'], struct_get_listing_item_layouts( 'struct_service' ) ) ? $_POST['struct_service_listing_item_layout'] : 'thumb' );
		update_post_meta( $post_id, 'struct_service_listing_posts_per_page', intval( $_POST['struct_service_listing_posts_per_page'] ) );

		update_post_meta( $post_id, 'struct_team_listing_base_category', intval( $_POST['struct_team_listing_base_category'] ) );
		update_post_meta( $post_id, 'struct_team_listing_layout', array_key_exists( $_POST['struct_team_listing_layout'], struct_get_listing_layouts() ) ? $_POST['struct_team_listing_layout'] : '2-sidebar' );
		update_post_meta( $post_id, 'struct_team_listing_posts_per_page', intval( $_POST['struct_team_listing_posts_per_page'] ) );

		update_post_meta( $post_id, 'struct_faq_listing_base_category', intval( $_POST['struct_faq_listing_base_category'] ) );

		update_post_meta( $post_id, 'struct_diy_listing_base_category', intval( $_POST['struct_diy_listing_base_category'] ) );
		update_post_meta( $post_id, 'struct_diy_listing_posts_per_page', intval( $_POST['struct_diy_listing_posts_per_page'] ) );
	}
	endif;

	if ( ! function_exists( 'struct_add_cpt_page_meta_box' ) ):
	function struct_add_cpt_page_meta_box( $post ) {
		struct_prepare_metabox( 'page' );

		?><div class="ci-cf-wrap"><?php
			struct_metabox_open_tab( '' );
				struct_metabox_checkbox( 'struct_hide_featured', 1, esc_html__( "Don't show the featured image when viewing this individual page.", 'struct' ) );
				struct_metabox_input( 'struct_subtitle', esc_html__( 'Subtitle (optional):', 'struct' ) );
			struct_metabox_close_tab();
		?></div><?php
	}
	endif;


	if ( ! function_exists( 'struct_add_page_project_listing_meta_box' ) ):
	function struct_add_page_project_listing_meta_box( $object, $box ) {
		struct_prepare_metabox( 'page' );

		?><div class="ci-cf-wrap"><?php
			struct_metabox_open_tab( '' );
				struct_metabox_guide( wp_kses( __( "Select a base category. Only items from the selected category will be displayed. If you don't select one (i.e. empty) items from all categories will be shown.", 'struct' ), struct_get_allowed_tags( 'guide' ) ) );
				?><p class="ci-field-group ci-field-dropdown"><label for="struct_project_base_category"><?php esc_html_e( 'Base category:', 'struct' ); ?></label> <?php
				$category = get_post_meta( $object->ID, 'struct_project_listing_base_category', true );
				wp_dropdown_categories( array(
					'selected'          => $category,
					'id'                => 'struct_project_listing_base_category',
					'name'              => 'struct_project_listing_base_category',
					'show_option_none'  => ' ',
					'option_none_value' => 0,
					'taxonomy'          => 'struct_project_category',
					'hierarchical'      => 1,
					'show_count'        => 1,
					'hide_empty'        => 0
				) );
				?></p><?php

				struct_metabox_dropdown( 'struct_project_listing_layout', struct_get_listing_layouts(), esc_html__( 'Listing layout:', 'struct' ) );
				struct_metabox_dropdown( 'struct_project_listing_item_layout', struct_get_listing_item_layouts( 'struct_project' ), esc_html__( 'Items layout:', 'struct' ) );
				struct_metabox_guide( wp_kses( sprintf( __( 'Set the number of items per page that you want to display. Setting this to <strong>-1</strong> will show <strong>all items</strong>>, while setting it to zero or leaving it empty, will follow the global option set from <em>Settings -> Reading</em>, currently set to <strong>%s items per page</strong>.', 'struct' ), get_option( 'posts_per_page' ) ), struct_get_allowed_tags( 'guide' ) ) );
				struct_metabox_input( 'struct_project_listing_posts_per_page', esc_html__( 'Items per page:', 'struct' ), array( 'input_type' => 'number' ) );
			struct_metabox_close_tab();
		?></div><?php

		struct_bind_metabox_to_page_template( 'struct-tpl-project-listing-meta', 'template-listing-struct_project.php' );
	}
	endif;


	if ( ! function_exists( 'struct_add_page_service_listing_meta_box' ) ):
	function struct_add_page_service_listing_meta_box( $object, $box ) {
		struct_prepare_metabox( 'page' );

		?><div class="ci-cf-wrap"><?php
			struct_metabox_open_tab( '' );
				struct_metabox_guide( wp_kses( __( "Select a base category. Only items from the selected category will be displayed. If you don't select one (i.e. empty) items from all categories will be shown.", 'struct' ), struct_get_allowed_tags( 'guide' ) ) );
				?><p class="ci-field-group ci-field-dropdown"><label for="struct_service_base_category"><?php esc_html_e( 'Base category:', 'struct' ); ?></label> <?php
				$category = get_post_meta( $object->ID, 'struct_service_listing_base_category', true );
				wp_dropdown_categories( array(
					'selected'          => $category,
					'id'                => 'struct_service_listing_base_category',
					'name'              => 'struct_service_listing_base_category',
					'show_option_none'  => ' ',
					'option_none_value' => 0,
					'taxonomy'          => 'struct_service_category',
					'hierarchical'      => 1,
					'show_count'        => 1,
					'hide_empty'        => 0
				) );
				?></p><?php

				struct_metabox_dropdown( 'struct_service_listing_layout', struct_get_listing_layouts(), esc_html__( 'Listing layout:', 'struct' ) );
				struct_metabox_dropdown( 'struct_service_listing_item_layout', struct_get_listing_item_layouts( 'struct_service' ), esc_html__( 'Items layout:', 'struct' ) );
				struct_metabox_guide( wp_kses( sprintf( __( 'Set the number of items per page that you want to display. Setting this to <strong>-1</strong> will show <strong>all items</strong>>, while setting it to zero or leaving it empty, will follow the global option set from <em>Settings -> Reading</em>, currently set to <strong>%s items per page</strong>.', 'struct' ), get_option( 'posts_per_page' ) ), struct_get_allowed_tags( 'guide' ) ) );
				struct_metabox_input( 'struct_service_listing_posts_per_page', esc_html__( 'Items per page:', 'struct' ), array( 'input_type' => 'number' ) );
			struct_metabox_close_tab();
		?></div><?php

		struct_bind_metabox_to_page_template( 'struct-tpl-service-listing-meta', 'template-listing-struct_service.php' );
	}
	endif;


	if ( ! function_exists( 'struct_add_page_team_listing_meta_box' ) ):
	function struct_add_page_team_listing_meta_box( $object, $box ) {
		struct_prepare_metabox( 'page' );

		?><div class="ci-cf-wrap"><?php
			struct_metabox_open_tab( '' );
				struct_metabox_guide( wp_kses( __( "Select a base category. Only items from the selected category will be displayed. If you don't select one (i.e. empty) items from all categories will be shown.", 'struct' ), struct_get_allowed_tags( 'guide' ) ) );
				?><p class="ci-field-group ci-field-dropdown"><label for="struct_team_base_category"><?php esc_html_e( 'Base category:', 'struct' ); ?></label> <?php
				$category = get_post_meta( $object->ID, 'struct_team_listing_base_category', true );
				wp_dropdown_categories( array(
					'selected'          => $category,
					'id'                => 'struct_team_listing_base_category',
					'name'              => 'struct_team_listing_base_category',
					'show_option_none'  => ' ',
					'option_none_value' => 0,
					'taxonomy'          => 'struct_team_category',
					'hierarchical'      => 1,
					'show_count'        => 1,
					'hide_empty'        => 0
				) );
				?></p><?php

				struct_metabox_dropdown( 'struct_team_listing_layout', struct_get_listing_layouts(), esc_html__( 'Listing layout:', 'struct' ) );
				struct_metabox_guide( wp_kses( sprintf( __( 'Set the number of items per page that you want to display. Setting this to <strong>-1</strong> will show <strong>all items</strong>>, while setting it to zero or leaving it empty, will follow the global option set from <em>Settings -> Reading</em>, currently set to <strong>%s items per page</strong>.', 'struct' ), get_option( 'posts_per_page' ) ), struct_get_allowed_tags( 'guide' ) ) );
				struct_metabox_input( 'struct_team_listing_posts_per_page', esc_html__( 'Items per page:', 'struct' ), array( 'input_type' => 'number' ) );
			struct_metabox_close_tab();
		?></div><?php

		struct_bind_metabox_to_page_template( 'struct-tpl-team-listing-meta', 'template-listing-struct_team.php' );
	}
	endif;

	if ( ! function_exists( 'struct_add_page_faq_listing_meta_box' ) ):
	function struct_add_page_faq_listing_meta_box( $object, $box ) {
		struct_prepare_metabox( 'page' );

		?><div class="ci-cf-wrap"><?php
			struct_metabox_open_tab( '' );
				struct_metabox_guide( wp_kses( __( "Select a base category. Only items from the selected category will be displayed. If you don't select one (i.e. empty) items from all categories will be shown.", 'struct' ), struct_get_allowed_tags( 'guide' ) ) );
				?><p class="ci-field-group ci-field-dropdown"><label for="struct_faq_base_category"><?php esc_html_e( 'Base category:', 'struct' ); ?></label> <?php
				$category = get_post_meta( $object->ID, 'struct_faq_listing_base_category', true );
				wp_dropdown_categories( array(
					'selected'          => $category,
					'id'                => 'struct_faq_listing_base_category',
					'name'              => 'struct_faq_listing_base_category',
					'show_option_none'  => ' ',
					'option_none_value' => 0,
					'taxonomy'          => 'struct_faq_category',
					'hierarchical'      => 1,
					'show_count'        => 1,
					'hide_empty'        => 0
				) );
				?></p><?php
			struct_metabox_close_tab();
		?></div><?php

		struct_bind_metabox_to_page_template( 'struct-tpl-faq-listing-meta', 'template-listing-struct_faq.php' );
	}
	endif;

	if ( ! function_exists( 'struct_add_page_diy_listing_meta_box' ) ):
	function struct_add_page_diy_listing_meta_box( $object, $box ) {
		struct_prepare_metabox( 'page' );

		?><div class="ci-cf-wrap"><?php
			struct_metabox_open_tab( '' );
				struct_metabox_guide( wp_kses( __( "Select a base category. Only items from the selected category will be displayed. If you don't select one (i.e. empty) items from all categories will be shown.", 'struct' ), struct_get_allowed_tags( 'guide' ) ) );
				?><p class="ci-field-group ci-field-dropdown"><label for="struct_diy_base_category"><?php esc_html_e( 'Base category:', 'struct' ); ?></label> <?php
				$category = get_post_meta( $object->ID, 'struct_diy_listing_base_category', true );
				wp_dropdown_categories( array(
					'selected'          => $category,
					'id'                => 'struct_diy_listing_base_category',
					'name'              => 'struct_diy_listing_base_category',
					'show_option_none'  => ' ',
					'option_none_value' => 0,
					'taxonomy'          => 'struct_diy_category',
					'hierarchical'      => 1,
					'show_count'        => 1,
					'hide_empty'        => 0
				) );
				?></p><?php

				struct_metabox_guide( wp_kses( sprintf( __( 'Set the number of items per page that you want to display. Setting this to <strong>-1</strong> will show <strong>all items</strong>>, while setting it to zero or leaving it empty, will follow the global option set from <em>Settings -> Reading</em>, currently set to <strong>%s items per page</strong>.', 'struct' ), get_option( 'posts_per_page' ) ), struct_get_allowed_tags( 'guide' ) ) );
				struct_metabox_input( 'struct_diy_listing_posts_per_page', esc_html__( 'Items per page:', 'struct' ), array( 'input_type' => 'number' ) );
			struct_metabox_close_tab();
		?></div><?php

		struct_bind_metabox_to_page_template( 'struct-tpl-diy-listing-meta', 'template-listing-struct_diy.php' );
	}
	endif;
