<?php
add_action( 'customize_register', 'struct_customize_register', 100 );
/**
 * Registers all theme-related options to the Customizer.
 *
 * @param WP_Customize_Manager $wpc Reference to the customizer's manager object.
 */
function struct_customize_register( $wpc ) {

	// Partial for various settings that affect the customizer styles, but can't have a dedicated icon, e.g. 'limit_logo_size'
	$wpc->selective_refresh->add_partial( 'theme_style', array(
		'selector'            => '#struct-style-inline-css',
		'render_callback'     => 'struct_get_all_customizer_css',
		'settings'            => array_keys( struct_get_registered_typography_controls() ),
		'container_inclusive' => false,
	) );

	$wpc->selective_refresh->add_partial( 'theme_gfonts', array(
		'selector'            => '#struct-user-google-fonts-css',
		'render_callback'     => 'struct_customize_preview_google_fonts',
		'settings'            => array_keys( struct_get_registered_typography_controls() ),
		'container_inclusive' => true,
	) );

	$wpc->get_panel( 'nav_menus' )->priority = 2;

	$wpc->add_section( 'layout', array(
		'title'    => esc_html_x( 'Layout Options', 'customizer section title', 'struct' ),
		'priority' => 20
	) );

	$wpc->add_section( 'typography', array(
		'title'    => _x( 'Typography Options', 'customizer section title', 'struct' ),
		'priority' => 40
	) );

	$wpc->get_section( 'header_image' )->title    = esc_html__( 'Header Colors', 'struct' );
	$wpc->get_section( 'header_image' )->priority = 45;

	$wpc->get_section( 'colors' )->title    = esc_html__( 'Content Colors', 'struct' );
	$wpc->get_section( 'colors' )->priority = 50;


	// The following line doesn't work in a some PHP versions. Apparently, get_panel( 'widgets' ) returns an array,
	// therefore a cast to object is needed. http://wordpress.stackexchange.com/questions/160987/warning-creating-default-object-when-altering-customize-panels
	//$wpc->get_panel( 'widgets' )->priority = 55;
	$panel_widgets = (object) $wpc->get_panel( 'widgets' );
	$panel_widgets->priority = 55;

	$wpc->add_section( 'sidebar_colors', array(
		'title'    => _x( 'Sidebar Colors', 'customizer section title', 'struct' ),
		'priority' => 60
	) );

	$wpc->add_section( 'social', array(
		'title'       => esc_html_x( 'Social Networks', 'customizer section title', 'struct' ),
		'description' => esc_html__( 'Enter your social network URLs. Leaving a URL empty will hide its respective icon.', 'struct' ),
		'priority'    => 70
	) );

	$wpc->add_panel( 'cpt_post_options', array(
		'title'       => esc_html_x( 'Post Options', 'customizer section title', 'struct' ),
		'description' => esc_html__( 'These options affect your post-related pages.', 'struct' ),
		'priority'    => 80
	) );

	$wpc->add_section( 'listing_post', array(
		'title' => esc_html_x( 'Post Listings', 'customizer section title', 'struct' ),
		'panel' => 'cpt_post_options',
	) );

	$wpc->add_section( 'single_post', array(
		'title' => esc_html_x( 'Single Posts', 'customizer section title', 'struct' ),
		'panel' => 'cpt_post_options',
	) );

	$wpc->add_panel( 'cpt_diy_options', array(
		'title'       => esc_html_x( 'DIY Options', 'customizer section title', 'struct' ),
		'description' => esc_html__( 'These options affect your DIY-related pages.', 'struct' ),
		'priority'    => 90
	) );

	$wpc->add_section( 'listing_diy', array(
		'title' => esc_html_x( 'DIY Listings', 'customizer section title', 'struct' ),
		'panel' => 'cpt_diy_options',
	) );

	$wpc->add_section( 'single_diy', array(
		'title' => esc_html_x( 'Single DIY', 'customizer section title', 'struct' ),
		'panel' => 'cpt_diy_options',
	) );

	$wpc->add_section( 'footer', array(
		'title'    => esc_html_x( 'Footer Options', 'customizer section title', 'struct' ),
		'priority' => 100
	) );

	// Section 'static_front_page' is not defined when there are no pages.
	if ( get_pages() ) {
		$wpc->get_section( 'static_front_page' )->priority = 110;
	}

	$wpc->add_section( 'titles', array(
		'title'    => esc_html_x( 'Titles', 'customizer section title', 'struct' ),
		'priority' => 120
	) );

	$wpc->add_section( 'other', array(
		'title'       => esc_html_x( 'Other', 'customizer section title', 'struct' ),
		'description' => esc_html__( 'Other options affecting the whole site.', 'struct' ),
		'priority'    => 130
	) );


	//
	// Group options by registering the setting first, and the control right after.
	//

	//
	// Layout
	//
	$wpc->add_setting( 'excerpt_length', array(
		'default'           => 55,
		'sanitize_callback' => 'absint',
	) );
	$wpc->add_control( 'excerpt_length', array(
		'type'        => 'number',
		'input_attrs' => array(
			'min'  => 10,
			'step' => 1,
		),
		'section'     => 'layout',
		'label'       => esc_html__( 'Automatically generated excerpt length (in words)', 'struct' ),
	) );

	$wpc->add_setting( 'pagination_method', array(
		'default'           => 'numbers',
		'sanitize_callback' => 'struct_sanitize_pagination_method',
	) );
	$wpc->add_control( 'pagination_method', array(
		'type'    => 'select',
		'section' => 'layout',
		'label'   => esc_html__( 'Pagination Method', 'struct' ),
		'choices' => array(
			'numbers' => esc_html_x( 'Numbered links', 'pagination method', 'struct' ),
			'text'    => esc_html_x( '"Previous - Next" links', 'pagination method', 'struct' ),
		),
	) );

	
	//
	// Typography
	//
	require_once get_theme_file_path( 'inc/customizer/sections/global/typography.php' );

	//
	// Header Image
	//
	$wpc->add_setting( 'header_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'struct_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'header_bg_color', array(
		'section'  => 'header_image',
		'priority' => 29,
		'label'    => esc_html__( 'Background Color', 'struct' ),
	) ) );

	$wpc->get_control( 'header_image' )->priority = 30;

	$wpc->add_setting( 'header_bg_repeat', array(
		'default'           => 'no-repeat',
		'sanitize_callback' => 'struct_sanitize_repeat_choices',
	) );
	$wpc->add_control( 'header_bg_repeat', array(
		'type'     => 'select',
		'section'  => 'header_image',
		'priority' => 30,
		'label'    => esc_html__( 'Background Image Repeat', 'struct' ),
		'choices'  => struct_get_repeat_choices(),
	) );

	$wpc->add_setting( 'header_bg_position_x', array(
		'default'           => 'left',
		'sanitize_callback' => 'struct_sanitize_bg_position_x',
	) );
	$wpc->add_control( 'header_bg_position_x', array(
		'type'     => 'select',
		'section'  => 'header_image',
		'priority' => 30,
		'label'    => esc_html__( 'Background Image Horizontal Position', 'struct' ),
		'choices'  => struct_get_bg_position_x_choices(),
	) );

	$wpc->add_setting( 'header_nav_color', array(
		'default'           => '#FFFFFF',
		'sanitize_callback' => 'struct_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'header_nav_color', array(
		'section'  => 'header_image',
		'priority' => 35,
		'label'    => esc_html__( 'Navigation & Logo Text Color', 'struct' )
	) ) );

	$wpc->add_setting( 'header_nav_color_hover', array(
		'default'           => '#FFFFFF',
		'sanitize_callback' => 'struct_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'header_nav_color_hover', array(
		'section'  => 'header_image',
		'priority' => 35,
		'label'    => esc_html__( 'Navigation Hover & Active Color', 'struct' )
	) ) );

	$wpc->add_setting( 'header_subnav_bg_color', array(
		'default'           => '#FFFFFF',
		'sanitize_callback' => 'struct_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'header_subnav_bg_color', array(
		'section'  => 'header_image',
		'priority' => 35,
		'label'    => esc_html__( 'Sub-Navigation Background Color', 'struct' )
	) ) );

	$wpc->add_setting( 'header_subnav_color', array(
		'default'           => '#313131',
		'sanitize_callback' => 'struct_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'header_subnav_color', array(
		'section'  => 'header_image',
		'priority' => 35,
		'label'    => esc_html__( 'Sub-Navigation Text Color', 'struct' )
	) ) );

	$wpc->add_setting( 'header_subnav_color_hover', array(
		'default'           => '#39b54a',
		'sanitize_callback' => 'struct_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'header_subnav_color_hover', array(
		'section'  => 'header_image',
		'priority' => 35,
		'label'    => esc_html__( 'Sub-Navigation Text Color Hover', 'struct' )
	) ) );



	//
	// Content colors
	//
	$wpc->get_control( 'background_image' )->section      = 'colors';
	$wpc->get_control( 'background_repeat' )->section     = 'colors';
	$wpc->get_control( 'background_attachment' )->section = 'colors';
	if ( ! is_null( $wpc->get_control( 'background_position_x' ) ) ) {
		$wpc->get_control( 'background_position_x' )->section = 'colors';
	} else {
		$wpc->get_control( 'background_position' )->section = 'colors';
		$wpc->get_control( 'background_preset' )->section   = 'colors';
		$wpc->get_control( 'background_size' )->section     = 'colors';
	}

	$wpc->add_setting( 'global_primary_color', array(
		'transport'         => 'postMessage',
		'default'           => '#39b54a',
		'sanitize_callback' => 'struct_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'global_primary_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Primary Color', 'struct' )
	) ) );

	$wpc->add_setting( 'text_on_primary_color', array(
		'transport'         => 'postMessage',
		'default'           => '#ffffff',
		'sanitize_callback' => 'struct_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'text_on_primary_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Text on Primary Color', 'struct' )
	) ) );

	$wpc->add_setting( 'global_text_color', array(
		'transport'         => 'postMessage',
		'default'           => '#313131',
		'sanitize_callback' => 'struct_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'global_text_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Text Color (Content)', 'struct' )
	) ) );

	$wpc->add_setting( 'global_link_color', array(
		'transport'         => 'postMessage',
		'default'           => '#39b54a',
		'sanitize_callback' => 'struct_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'global_link_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Content Link Color', 'struct' )
	) ) );

	$wpc->add_setting( 'global_link_hover_color', array(
		'transport'         => 'postMessage',
		'default'           => '#33a242',
		'sanitize_callback' => 'struct_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'global_link_hover_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Content Link Hover Color', 'struct' )
	) ) );

	$wpc->add_setting( 'global_border_color', array(
		'transport'         => 'postMessage',
		'default'           => '#ebebeb',
		'sanitize_callback' => 'struct_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'global_border_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Global Border Color', 'struct' )
	) ) );



	//
	// Sidebar colors
	//
	$wpc->add_setting( 'sidebar_bg_color', array(
		'transport'         => 'postMessage',
		'default'           => '',
		'sanitize_callback' => 'struct_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'sidebar_bg_color', array(
		'section' => 'sidebar_colors',
		'label'   => esc_html__( 'Background Color', 'struct' ),
	) ) );

	$wpc->add_setting( 'sidebar_text_color', array(
		'transport'         => 'postMessage',
		'default'           => '#313131',
		'sanitize_callback' => 'struct_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'sidebar_text_color', array(
		'section' => 'sidebar_colors',
		'label'   => esc_html__( 'Text Color', 'struct' ),
	) ) );

	$wpc->add_setting( 'sidebar_link_color', array(
		'transport'         => 'postMessage',
		'default'           => '#39b54a',
		'sanitize_callback' => 'struct_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'sidebar_link_color', array(
		'section' => 'sidebar_colors',
		'label'   => esc_html__( 'Link Color', 'struct' ),
	) ) );

	$wpc->add_setting( 'sidebar_hover_color', array(
		'transport'         => 'postMessage',
		'default'           => '#33a242',
		'sanitize_callback' => 'struct_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'sidebar_hover_color', array(
		'section' => 'sidebar_colors',
		'label'   => esc_html__( 'Link Hover Color', 'struct' ),
	) ) );

	$wpc->add_setting( 'sidebar_title_color', array(
		'transport'         => 'postMessage',
		'default'           => '#313131',
		'sanitize_callback' => 'struct_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'sidebar_title_color', array(
		'section' => 'sidebar_colors',
		'label'   => esc_html__( 'Widget Titles Color', 'struct' ),
	) ) );

	$wpc->add_setting( 'sidebar_border_color', array(
		'transport'         => 'postMessage',
		'default'           => '#ebebeb',
		'sanitize_callback' => 'struct_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'sidebar_border_color', array(
		'section' => 'sidebar_colors',
		'label'   => esc_html__( 'Border Color', 'struct' ),
	) ) );



	//
	// Social
	//
	$wpc->add_setting( 'social_target', array(
		'default'           => 1,
		'sanitize_callback' => 'struct_sanitize_checkbox',
	) );
	$wpc->add_control( 'social_target', array(
		'type'    => 'checkbox',
		'section' => 'social',
		'label'   => esc_html__( 'Open social and sharing links in a new tab.', 'struct' ),
	) );

	$networks = struct_get_social_networks();

	foreach ( $networks as $network ) {
		$wpc->add_setting( 'social_' . $network['name'], array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		) );
		$wpc->add_control( 'social_' . $network['name'], array(
			'type'    => 'url',
			'section' => 'social',
			'label'   => esc_html( sprintf( _x( '%s URL', 'social network url', 'struct' ), $network['label'] ) ),
		) );
	}

	$wpc->add_setting( 'rss_feed', array(
		'default'           => get_bloginfo( 'rss2_url' ),
		'sanitize_callback' => 'esc_url_raw',
	) );
	$wpc->add_control( 'rss_feed', array(
		'type'    => 'url',
		'section' => 'social',
		'label'   => esc_html__( 'RSS Feed', 'struct' ),
	) );



	//
	// Listing Post
	//
	$wpc->add_setting( 'listing_post_date', array(
		'default'           => 1,
		'sanitize_callback' => 'struct_sanitize_checkbox',
	) );
	$wpc->add_control( 'listing_post_date', array(
		'type'    => 'checkbox',
		'section' => 'listing_post',
		'label'   => esc_html__( 'Show date.', 'struct' ),
	) );

	$wpc->add_setting( 'listing_post_categories', array(
		'default'           => 1,
		'sanitize_callback' => 'struct_sanitize_checkbox',
	) );
	$wpc->add_control( 'listing_post_categories', array(
		'type'    => 'checkbox',
		'section' => 'listing_post',
		'label'   => esc_html__( 'Show categories.', 'struct' ),
	) );

	$wpc->add_setting( 'listing_post_comments', array(
		'default'           => 1,
		'sanitize_callback' => 'struct_sanitize_checkbox',
	) );
	$wpc->add_control( 'listing_post_comments', array(
		'type'    => 'checkbox',
		'section' => 'listing_post',
		'label'   => esc_html__( 'Show comments.', 'struct' ),
	) );

	$wpc->add_setting( 'listing_post_featured', array(
		'default'           => 1,
		'sanitize_callback' => 'struct_sanitize_checkbox',
	) );
	$wpc->add_control( 'listing_post_featured', array(
		'type'    => 'checkbox',
		'section' => 'listing_post',
		'label'   => esc_html__( 'Show featured image.', 'struct' ),
	) );



	//
	// Single Post
	//
	$wpc->add_setting( 'single_date', array(
		'default'           => 1,
		'sanitize_callback' => 'struct_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_date', array(
		'type'    => 'checkbox',
		'section' => 'single_post',
		'label'   => esc_html__( 'Show date.', 'struct' ),
	) );

	$wpc->add_setting( 'single_categories', array(
		'default'           => 1,
		'sanitize_callback' => 'struct_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_categories', array(
		'type'    => 'checkbox',
		'section' => 'single_post',
		'label'   => esc_html__( 'Show categories.', 'struct' ),
	) );

	$wpc->add_setting( 'single_tags', array(
		'default'           => 1,
		'sanitize_callback' => 'struct_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_tags', array(
		'type'    => 'checkbox',
		'section' => 'single_post',
		'label'   => esc_html__( 'Show tags.', 'struct' ),
	) );

	$wpc->add_setting( 'single_comments', array(
		'default'           => 1,
		'sanitize_callback' => 'struct_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_comments', array(
		'type'    => 'checkbox',
		'section' => 'single_post',
		'label'   => esc_html__( 'Show comments.', 'struct' ),
	) );

	$wpc->add_setting( 'single_featured', array(
		'default'           => 1,
		'sanitize_callback' => 'struct_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_featured', array(
		'type'    => 'checkbox',
		'section' => 'single_post',
		'label'   => esc_html__( 'Show featured image.', 'struct' ),
	) );



	//
	// Listing DIY
	//
	$wpc->add_setting( 'listing_diy_date', array(
		'default'           => 1,
		'sanitize_callback' => 'struct_sanitize_checkbox',
	) );
	$wpc->add_control( 'listing_diy_date', array(
		'type'    => 'checkbox',
		'section' => 'listing_diy',
		'label'   => esc_html__( 'Show date.', 'struct' ),
	) );

	$wpc->add_setting( 'listing_diy_categories', array(
		'default'           => 1,
		'sanitize_callback' => 'struct_sanitize_checkbox',
	) );
	$wpc->add_control( 'listing_diy_categories', array(
		'type'    => 'checkbox',
		'section' => 'listing_diy',
		'label'   => esc_html__( 'Show categories.', 'struct' ),
	) );

	$wpc->add_setting( 'listing_diy_comments', array(
		'default'           => 1,
		'sanitize_callback' => 'struct_sanitize_checkbox',
	) );
	$wpc->add_control( 'listing_diy_comments', array(
		'type'    => 'checkbox',
		'section' => 'listing_diy',
		'label'   => esc_html__( 'Show comments.', 'struct' ),
	) );

	$wpc->add_setting( 'listing_diy_featured', array(
		'default'           => 1,
		'sanitize_callback' => 'struct_sanitize_checkbox',
	) );
	$wpc->add_control( 'listing_diy_featured', array(
		'type'    => 'checkbox',
		'section' => 'listing_diy',
		'label'   => esc_html__( 'Show featured image.', 'struct' ),
	) );



	//
	// Single DIY
	//
	$wpc->add_setting( 'single_diy_date', array(
		'default'           => 1,
		'sanitize_callback' => 'struct_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_diy_date', array(
		'type'    => 'checkbox',
		'section' => 'single_diy',
		'label'   => esc_html__( 'Show date.', 'struct' ),
	) );

	$wpc->add_setting( 'single_diy_categories', array(
		'default'           => 1,
		'sanitize_callback' => 'struct_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_diy_categories', array(
		'type'    => 'checkbox',
		'section' => 'single_diy',
		'label'   => esc_html__( 'Show categories.', 'struct' ),
	) );

	$wpc->add_setting( 'single_diy_comments', array(
		'default'           => 1,
		'sanitize_callback' => 'struct_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_diy_comments', array(
		'type'    => 'checkbox',
		'section' => 'single_diy',
		'label'   => esc_html__( 'Show comments.', 'struct' ),
	) );

	$wpc->add_setting( 'single_diy_featured', array(
		'default'           => 1,
		'sanitize_callback' => 'struct_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_diy_featured', array(
		'type'    => 'checkbox',
		'section' => 'single_diy',
		'label'   => esc_html__( 'Show featured image.', 'struct' ),
	) );



	//
	// Titles
	//
	$wpc->add_setting( 'title_blog', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wpc->add_control( 'title_blog', array(
		'type'        => 'text',
		'section'     => 'titles',
		'label'       => esc_html__( 'Blog Section Title', 'struct' ),
		'description' => wp_kses( __( "If provided, this option will override the page title, if you have set a <strong>Posts page</strong> in Settings > Reading > Front page displays.", 'struct' ), struct_get_allowed_tags() ),
	) );

	$wpc->add_setting( 'title_blog_subtitle', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wpc->add_control( 'title_blog_subtitle', array(
		'type'        => 'text',
		'section'     => 'titles',
		'label'       => esc_html__( 'Blog Section Subtitle', 'struct' ),
		'description' => wp_kses( __( "If provided, this option will override the page subtitle, if you have set a <strong>Posts page</strong> in Settings > Reading > Front page displays.", 'struct' ), struct_get_allowed_tags() ),
	) );

	$wpc->add_setting( 'title_diy', array(
		'default'           => esc_html__( 'Do it yourself', 'struct' ),
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wpc->add_control( 'title_diy', array(
		'type'    => 'text',
		'section' => 'titles',
		'label'   => esc_html__( 'DIY Title', 'struct' ),
	) );

	$wpc->add_setting( 'title_search', array(
		'default'           => esc_html__( 'Search results', 'struct' ),
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wpc->add_control( 'title_search', array(
		'type'    => 'text',
		'section' => 'titles',
		'label'   => esc_html__( 'Search Title', 'struct' ),
	) );

	$wpc->add_setting( 'title_404', array(
		'default'           => esc_html__( 'Page not found', 'struct' ),
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wpc->add_control( 'title_404', array(
		'type'    => 'text',
		'section' => 'titles',
		'label'   => esc_html__( '404 (Not Found) Title', 'struct' ),
	) );



	//
	// Footer
	//
	$wpc->add_setting( 'footer_bg_color', array(
		'transport'         => 'postMessage',
		'default'           => '#302e2f',
		'sanitize_callback' => 'struct_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'footer_bg_color', array(
		'section' => 'footer',
		'label'   => esc_html__( 'Background Color', 'struct' )
	) ) );

	$wpc->add_setting( 'footer_text_color', array(
		'transport'         => 'postMessage',
		'default'           => '#FFFFFF',
		'sanitize_callback' => 'struct_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'footer_text_color', array(
		'section' => 'footer',
		'label'   => esc_html__( 'Text Color', 'struct' )
	) ) );

	$wpc->add_setting( 'footer_link_color', array(
		'transport'         => 'postMessage',
		'default'           => '#FFFFFF',
		'sanitize_callback' => 'struct_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'footer_link_color', array(
		'section' => 'footer',
		'label'   => esc_html__( 'Link Color', 'struct' )
	) ) );

	$wpc->add_setting( 'footer_back_to_top', array(
		'default'           => 1,
		'sanitize_callback' => 'struct_sanitize_checkbox',
	) );
	$wpc->add_control( 'footer_back_to_top', array(
		'type'    => 'checkbox',
		'section' => 'footer',
		'label'   => esc_html__( 'Show floating "Back To Top" button.', 'struct' ),
	) );

	$wpc->add_setting( 'footer_text', array(
		'default'           => struct_get_default_footer_text(),
		'sanitize_callback' => 'struct_sanitize_footer_text',
	) );
	$wpc->add_control( 'footer_text', array(
		'type'        => 'text',
		'section'     => 'footer',
		'label'       => esc_html__( 'Footer Text Left', 'struct' ),
		'description' => esc_html__( 'Allowed tags: a (href|class), img (src|class), span (class), i (class), b, em, strong.', 'struct' ),
	) );

	$wpc->add_setting( 'footer_text_right', array(
		'default'           => struct_get_default_footer_text( 'right' ),
		'sanitize_callback' => 'struct_sanitize_footer_text',
	) );
	$wpc->add_control( 'footer_text_right', array(
		'type'        => 'text',
		'section'     => 'footer',
		'label'       => esc_html__( 'Footer Text Right', 'struct' ),
		'description' => esc_html__( 'Allowed tags: a (href|class), img (src|class), span (class), i (class), b, em, strong.', 'struct' ),
	) );



	//
	// Other
	//
	$wpc->add_setting( 'google_anaytics_tracking_id', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wpc->add_control( 'google_anaytics_tracking_id', array(
		'type'        => 'text',
		'section'     => 'other',
		'label'       => esc_html__( 'Google Analytics Tracking ID', 'struct' ),
		'description' => wp_kses( sprintf( __( 'Tracking is enabled only for the non-admin portion of your website. If you need fine-grained control of the tracking code, you are strongly adviced to <a href="%s" target="_blank">use a specialty plugin</a> instead.', 'struct' ), 'https://wordpress.org/plugins/search.php?q=analytics' ), struct_get_allowed_tags( 'guide' ) ),
	) );



	//
	// title_tagline Section
	//
	$wpc->add_setting( 'show_site_title', array(
		'default'           => 1,
		'sanitize_callback' => 'struct_sanitize_checkbox',
	) );
	$wpc->add_control( 'show_site_title', array(
		'type'     => 'checkbox',
		'section'  => 'title_tagline',
		'priority' => 8,
		'label'    => esc_html__( 'Show site title.', 'struct' ),
	) );

}

add_action( 'customize_register', 'struct_customize_register_custom_controls', 9 );
/**
 * Registers custom Customizer controls.
 *
 * @param WP_Customize_Manager $wpc Reference to the customizer's manager object.
 */
function struct_customize_register_custom_controls( $wpc ) {
	require_once get_theme_file_path( '/inc/customizer-controls/typography/typography.php' );
	$wpc->register_control_type( 'Struct_Customize_Typography_Control' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function struct_customize_preview_js() {
	$theme = wp_get_theme();
	// Generic preview code.
	wp_enqueue_script( 'struct-customizer-preview', get_theme_file_uri( '/inc/customizer/preview/preview.js' ), array( 'jquery' ), $theme->get( 'Version' ), true );

	wp_enqueue_script( 'struct-customizer-preview-colors', get_template_directory_uri() . '/js/customizer-preview.js', array( 'customize-preview' ), $theme->get( 'Version' ), true );

	// Options-specific preview code.
	wp_enqueue_script( 'struct-customizer-preview-global', get_theme_file_uri( '/inc/customizer/preview/global.js' ), array( 'jquery' ), $theme->get( 'Version' ), true );
}
add_action( 'customize_preview_init', 'struct_customize_preview_js' );

function struct_customize_controls_js() {
	$theme = wp_get_theme();
	wp_enqueue_style( 'struct-customizer-controls', get_theme_file_uri( '/inc/customizer-controls/style.css' ), array(), $theme->get( 'Version' ) );
}
add_action( 'customize_controls_enqueue_scripts', 'struct_customize_controls_js' );

function struct_typography_control_defaults_empty_breakpoints( $override_breakpoints = array() ) {
	$defaults = array(
		'desktop' => array(
			'family'     => '',
			'variant'    => '',
			'size'       => '',
			'lineHeight' => '',
			'transform'  => '',
			'spacing'    => '',
			'is_gfont'   => false,
		),
		'tablet'  => array(
			'family'     => '',
			'variant'    => '',
			'size'       => '',
			'lineHeight' => '',
			'transform'  => '',
			'spacing'    => '',
			'is_gfont'   => false,
		),
		'mobile'  => array(
			'family'     => '',
			'variant'    => '',
			'size'       => '',
			'lineHeight' => '',
			'transform'  => '',
			'spacing'    => '',
			'is_gfont'   => false,
		),
	);

	$return = array();
	foreach ( $defaults as $breakpoint => $values ) {
		if ( isset( $override_breakpoints[ $breakpoint ] ) && is_array( $override_breakpoints[ $breakpoint ] ) ) {
			$return[ $breakpoint ] = array_merge( $values, $override_breakpoints[ $breakpoint ] );
		} else {
			$return[ $breakpoint ] = $values;
		}
	}

	return $return;
}

function struct_sanitize_typography_control_breakpoints( $values ) {
	$defaults = struct_typography_control_defaults_empty_breakpoints();

	if ( ! empty( $values ) && is_string( $values ) ) {
		$values = json_decode( $values, true );
	}

	if ( ! is_array( $values ) ) {
		return $defaults;
	}

	$values = wp_parse_args( $values, $defaults );

	foreach ( $values as $breakpoint => $value ) {
		if ( ! array_key_exists( $breakpoint, $defaults ) ) {
			unset( $values[ $breakpoint ] );
		}
	}

	$new_values = array();

	foreach ( $values as $breakpoint => $breakpoint_values ) {
		if ( array_key_exists( $breakpoint, $defaults ) ) {
			$new_breakpoint_values = wp_parse_args( $breakpoint_values, $defaults[ $breakpoint ] );

			$new_breakpoint_values['family']     = sanitize_text_field( $new_breakpoint_values['family'] );
			$new_breakpoint_values['variant']    = sanitize_text_field( $new_breakpoint_values['variant'] );
			$new_breakpoint_values['size']       = struct_sanitize_intval_or_empty( $new_breakpoint_values['size'] );
			$new_breakpoint_values['lineHeight'] = struct_sanitize_floatval_or_empty( $new_breakpoint_values['lineHeight'] );
			$new_breakpoint_values['transform']  = sanitize_text_field( $new_breakpoint_values['transform'] );
			$new_breakpoint_values['spacing']    = struct_sanitize_floatval_or_empty( $new_breakpoint_values['spacing'] );
			$new_breakpoint_values['is_gfont']   = (bool) intval( $new_breakpoint_values['is_gfont'] );

			$new_values[ $breakpoint ] = $new_breakpoint_values;
		}
	}

	return $new_values;
}

/**
 * Customizer partial callbacks.
 */
require_once get_theme_file_path( '/inc/customizer/partial-callbacks.php' );

/**
 * CSS Generator.
 */
require_once get_theme_file_path( '/inc/customizer/class-struct-customizer-css-generator.php' );

/**
 * Customizer generated styles.
 */
require_once get_theme_file_path( '/inc/customizer/generated-styles.php' );
