<?php
namespace Elementor;

use Elementor\Group_Control_Base;

trait ElementsCommonFunctions {

	/**
	 * For Exclude Option
	 */
	public function add_exclude_controls() {
		$this->add_control(
			'post__not_in',
			[
				'label'       => __( 'Exclude', 'struct' ),
				'type'        => Controls_Manager::SELECT2,
				'options'     => Struct_Element_Helper::get_all_post_type_items(),
				'label_block' => true,
				'post_type'   => '',
				'multiple'    => true,
				'condition'   => [
					'struct_element_posts_post_type!' => 'by_id',
				],
			]
		);
	}

	protected function query_controls() {

		$this->add_group_control(
			Struct_Element_Posts_Group_Control::get_type(),
			[
				'name' => 'struct_element_posts',
			]
		);

		$this->add_exclude_controls();

		$this->add_control(
			'posts_per_page',
			[
				'label'     => __( 'Posts Per Page', 'struct' ),
				'type'      => Controls_Manager::NUMBER,
				'default'   => '4',
				'condition' => [
					'struct_element_posts_post_type!' => 'by_id',
				],
			]
		);

		$this->add_control(
			'offset',
			[
				'label'     => __( 'Offset', 'struct' ),
				'type'      => Controls_Manager::NUMBER,
				'default'   => '0',
				'condition' => [
					'struct_element_posts_post_type!' => 'by_id',
				],
			]
		);

		$this->add_control(
			'orderby',
			[
				'label'   => __( 'Order By', 'struct' ),
				'type'    => Controls_Manager::SELECT,
				'options' => Struct_Element_Helper::get_post_orderby_options(),
				'default' => 'date',

			]
		);

		$this->add_control(
			'order',
			[
				'label'   => __( 'Order', 'struct' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'asc'  => 'Ascending',
					'desc' => 'Descending',
				],
				'default' => 'desc',

			]
		);

	}

	protected function appearance_controls( $pt_source ) {

		$this->add_control(
			'show_thumbnail',
			[
				'label'        => __( 'Show Thumbnail', 'struct' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'struct' ),
				'label_off'    => __( 'Hide', 'struct' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);

		$this->add_control(
			'show_icon',
			[
				'label'        => __( 'Show Icon', 'struct' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'struct' ),
				'label_off'    => __( 'Hide', 'struct' ),
				'return_value' => 'yes',
				'default'      => 'yes',
				'condition'    => [
					$pt_source => [ 'struct_service' ],
				],
			]
		);

		$this->add_control(
			'icon_position',
			[
				'label'     => __( 'Icon Position', 'struct' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'center',
				'options'   => [
					'center'  => __( 'Center', 'struct' ),
					'left'    => __( 'Left', 'struct' ),
				],
				'condition' => [
					$pt_source => [ 'struct_service' ],
				],
			]
		);

		$this->add_control(
			'show_title',
			[
				'label'        => __( 'Show Title', 'struct' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'struct' ),
				'label_off'    => __( 'Hide', 'struct' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);

		$this->add_control(
			'show_meta',
			[
				'label'        => __( 'Show Meta', 'struct' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'struct' ),
				'label_off'    => __( 'Hide', 'struct' ),
				'return_value' => 'yes',
				'default'      => 'yes',
				'condition'    => [
					$pt_source => [ 'post', 'struct_diy', 'by_id' ],
				],
			]
		);

		$this->add_control(
			'show_socials',
			[
				'label'        => __( 'Show Socials', 'struct' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'struct' ),
				'label_off'    => __( 'Hide', 'struct' ),
				'return_value' => 'yes',
				'default'      => 'yes',
				'condition'    => [
					$pt_source => [ 'struct_team' ],
				],
			]
		);

		$this->add_control(
			'show_excerpt',
			[
				'label'        => __( 'Show Excerpt', 'struct' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'struct' ),
				'label_off'    => __( 'Hide', 'struct' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);

		$this->add_control(
			'show_button',
			[
				'label'        => __( 'Show Button', 'struct' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'struct' ),
				'label_off'    => __( 'Hide', 'struct' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);

	}
}
