<?php
namespace Elementor;

class Struct_Element extends Widget_Base {

	use \Elementor\ElementsCommonFunctions;

	public function get_name() {
		return 'struct_element';
	}

	public function get_title() {
		return __( 'Struct Element', 'struct' );
	}

	public function get_icon() {
		return 'eicon-wordpress';
	}

	public function get_categories() {
		return [ 'struct-elements' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_title',
			[
				'label' => __( 'Struct Element', 'struct' ),
			]
		);

		$this->add_control(
			'columns',
			[
				'label'   => __( 'Columns', 'struct' ),
				'type'    => Controls_Manager::SELECT,
				'default' => '2',
				'options' => [
					'2' => __( '2', 'struct' ),
					'3' => __( '3', 'struct' ),
					'4' => __( '4', 'struct' ),
				],
			]
		);

		$this->query_controls();

		$this->appearance_controls( 'struct_element_posts_post_type' );

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style_accent',
			[
				'label' => __( 'Primary Color', 'struct' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'accent_color',
			[
				'label'     => __( 'Primary Color', 'struct' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .section-title-wrap::after,{{WRAPPER}} .item-title::after,{{WRAPPER}} a.btn, {{WRAPPER}} .item-entry-time::after,{{WRAPPER}} .social-icon' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .item-icon' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} a.btn:hover, {{WRAPPER}} .item-title a:hover,{{WRAPPER}} .social-icon:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .entry-content p > a' => 'border-bottom-color: {{VALUE}}'
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style_text',
			[
				'label' => __( 'Secondary Color', 'struct' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'text_color',
			[
				'label'     => __( 'Secondary Color', 'struct' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .entry-meta'        => 'color: {{VALUE}};',
					'{{WRAPPER}} .entry-content'     => 'color: {{VALUE}};',
					'{{WRAPPER}} a.btn'              => 'color: {{VALUE}};',
					'{{WRAPPER}} .social-icon'       => 'color: {{VALUE}};',
					'{{WRAPPER}} a.btn:hover'        => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .social-icon:hover' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .item-title a'      => 'color: {{VALUE}};',
				],
				'scheme'    => [
					'type'  => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_3,
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'item_style_title',
			[
				'label' => __( 'Item Title Styles', 'struct' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_title_typography',
				'scheme'   => Scheme_Typography::TYPOGRAPHY_3,
				'selector' => '{{WRAPPER}} .item-title',
			]
		);

		$this->start_controls_tabs( 'tabs_meta_style' );

		$this->start_controls_tab(
			'tab_item_title_normal',
			[
				'label' => __( 'Normal', 'struct' ),
			]
		);

		$this->add_control(
			'item_title_text_color',
			[
				'label'     => __( 'Text Color', 'struct' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .item-title a' => 'color: {{VALUE}};',
				],
				'scheme'    => [
					'type'  => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_3,
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_item_title_hover',
			[
				'label' => __( 'Hover', 'struct' ),
			]
		);

		$this->add_control(
			'item_title_text_color_hover',
			[
				'label'     => __( 'Text Color', 'struct' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .item-title a:hover' => 'color: {{VALUE}};',
				],
				'scheme'    => [
					'type'  => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_3,
				],
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();

		$this->start_controls_section(
			'item_style_meta',
			[
				'label' => __( 'Item Meta Styles', 'struct' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_meta_typography',
				'scheme'   => Scheme_Typography::TYPOGRAPHY_3,
				'selector' => '{{WRAPPER}} .item-entry-time',
			]
		);

		$this->add_control(
			'item_meta_text_color',
			[
				'label'     => __( 'Text Color', 'struct' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .item-entry-time' => 'color: {{VALUE}};',
				],
				'scheme'    => [
					'type'  => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_3,
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'item_style_excerpt',
			[
				'label' => __( 'Item Excerpt Styles', 'struct' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_excerpt_typography',
				'scheme'   => Scheme_Typography::TYPOGRAPHY_3,
				'selector' => '{{WRAPPER}} .item-content > p',
			]
		);

		$this->add_control(
			'item_excerpt_text_color',
			[
				'label'     => __( 'Text Color', 'struct' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .item-content > p' => 'color: {{VALUE}};',
				],
				'scheme'    => [
					'type'  => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_3,
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style_button',
			[
				'label' => __( 'Button', 'struct-plugin' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'typography',
				'scheme'   => Scheme_Typography::TYPOGRAPHY_4,
				'selector' => '{{WRAPPER}} a.btn',
			]
		);

		$this->start_controls_tabs( 'tabs_button_style' );

		$this->start_controls_tab(
			'tab_button_normal',
			[
				'label' => __( 'Normal', 'struct-plugin' ),
			]
		);

		$this->add_control(
			'button_text_color',
			[
				'label'     => __( 'Text Color', 'struct-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} a.btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'background_color',
			[
				'label'     => __( 'Background Color', 'struct-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'scheme'    => [
					'type'  => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_4,
				],
				'selectors' => [
					'{{WRAPPER}} a.btn' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			[
				'label' => __( 'Hover', 'struct-plugin' ),
			]
		);

		$this->add_control(
			'hover_color',
			[
				'label'     => __( 'Text Color', 'struct-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} a.btn:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_background_hover_color',
			[
				'label'     => __( 'Background Color', 'struct-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} a.btn:hover' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_border_color',
			[
				'label'     => __( 'Border Color', 'struct-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} a.btn:hover' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'      => 'border',
				'selector'  => '{{WRAPPER}} a.btn',
				'separator' => 'before',
			]
		);

		$this->add_control(
			'border_radius',
			[
				'label'      => __( 'Border Radius', 'struct-plugin' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} a.btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'button_box_shadow',
				'selector' => '{{WRAPPER}} a.btn',
			]
		);

		$this->add_responsive_control(
			'text_padding',
			[
				'label'      => __( 'Padding', 'struct-plugin' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors'  => [
					'{{WRAPPER}} a.btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator'  => 'before',
			]
		);

		$this->end_controls_section();
	}

	protected function render() {
		$settings   = $this->get_settings();
		$columns    = intval( $settings['columns'] );
		$query_args = Struct_Element_Helper::get_query_args( 'struct_element_posts', $settings );

		$q = new \WP_Query( $query_args );

		if ( $q->have_posts() ) {
			?>
			<div class="row row-equal row-items">
			<?php

			while ( $q->have_posts() ) {
				$q->the_post();

				?>
					<div class="<?php echo esc_attr( struct_get_columns_classes( $columns ) ); ?>">
						<?php
						$template_path = 'template-parts/elementor/item.php';

						include locate_template( $template_path, false, false );
						?>
					</div>
				<?php
			}

			?>
			</div>
			<?php

			wp_reset_postdata();
		}

	}

}
