<?php
namespace Elementor;

class Widget_Post_Type extends Widget_Base {

	use \Elementor\ElementsCommonFunctions;

	public function get_name() {
		return 'post_type_widget';
	}

	public function get_title() {
		return __( 'Struct Post Type', 'struct' );
	}

	public function get_icon() {
		return 'eicon-wordpress';
	}

	public function get_categories() {
		return [ 'struct-elements' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_title',
			[
				'label' => __( 'Struct Post Type', 'struct' ),
			]
		);

		$this->add_control(
			'html_msg',
			[
				'type'            => Controls_Manager::RAW_HTML,
				'raw'             => __( 'Display any post type item from Struct by first selecting the post type, e.g. "Projects" and then the item itself.', 'struct' ),
				'content_classes' => 'ci-description',
			]
		);

		$this->add_control(
			'post_types',
			[
				'label'   => __( 'Post Type', 'struct' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'post',
				'options' => Struct_Element_Helper::element_post_types(),
			]
		);

		foreach ( Struct_Element_Helper::element_post_types() as $slug => $name ) {
			$this->add_control(
				'selected_post_' . $slug,
				[
					'label'       => __( 'Item', 'struct' ),
					'type'        => Controls_Manager::SELECT,
					'default'     => '',
					'label_block' => true,
					'options'     => Struct_Element_Helper::get_all_post_type_items( $slug ),
					'condition'   => [
						'post_types' => $slug,
					],
				]
			);
		}

		$this->appearance_controls( 'post_types' );

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style_accent',
			[
				'label' => __( 'Primary Color', 'struct' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'accent_color',
			[
				'label'     => __( 'Primary Color', 'struct' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .entry-meta::after,{{WRAPPER}} a.btn' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} a.btn:hover,{{WRAPPER}} .entry-title a:hover,{{WRAPPER}} .entry-meta-item::after, {{WRAPPER}} .entry-meta-item a:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style_text',
			[
				'label' => __( 'Secondary Color', 'struct' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'secondary_color',
			[
				'label'     => __( 'Secondary Color', 'struct' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .entry-meta'    => 'color: {{VALUE}};',
					'{{WRAPPER}} .entry-content' => 'color: {{VALUE}};',
					'{{WRAPPER}} a.btn'          => 'color: {{VALUE}};',
					'{{WRAPPER}} a.btn:hover'    => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .entry-title a' => 'color: {{VALUE}};',
				],
				'scheme'    => [
					'type'  => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_3,
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'item_style_title',
			[
				'label' => __( 'Item Title Styles', 'struct' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_title_typography',
				'scheme'   => Scheme_Typography::TYPOGRAPHY_3,
				'selector' => '{{WRAPPER}} .entry-title',
			]
		);

		$this->start_controls_tabs( 'tabs_meta_style' );

		$this->start_controls_tab(
			'tab_item_title_normal',
			[
				'label' => __( 'Normal', 'struct' ),
			]
		);

		$this->add_control(
			'item_title_text_color',
			[
				'label'     => __( 'Text Color', 'struct' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .entry-title a' => 'color: {{VALUE}};',
				],
				'scheme'    => [
					'type'  => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_3,
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_item_title_hover',
			[
				'label' => __( 'Hover', 'struct' ),
			]
		);

		$this->add_control(
			'item_title_text_color_hover',
			[
				'label'     => __( 'Text Color', 'struct' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .entry-title a:hover' => 'color: {{VALUE}};',
				],
				'scheme'    => [
					'type'  => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_3,
				],
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();

		$this->start_controls_section(
			'item_style_meta',
			[
				'label' => __( 'Item Meta Styles', 'struct' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_meta_typography',
				'scheme'   => Scheme_Typography::TYPOGRAPHY_3,
				'selector' => '{{WRAPPER}} .entry-meta-item',
			]
		);

		$this->add_control(
			'item_meta_text_color',
			[
				'label'     => __( 'Text Color', 'struct' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .entry-meta-item, {{WRAPPER}} .entry-meta-item a' => 'color: {{VALUE}};',
				],
				'scheme'    => [
					'type'  => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_3,
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'item_style_excerpt',
			[
				'label' => __( 'Item Excerpt Styles', 'struct' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_excerpt_typography',
				'scheme'   => Scheme_Typography::TYPOGRAPHY_3,
				'selector' => '{{WRAPPER}} .entry-content',
			]
		);

		$this->add_control(
			'item_excerpt_text_color',
			[
				'label'     => __( 'Text Color', 'struct' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .entry-content' => 'color: {{VALUE}};',
				],
				'scheme'    => [
					'type'  => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_3,
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style_button',
			[
				'label' => __( 'Button', 'struct-plugin' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'typography',
				'scheme'   => Scheme_Typography::TYPOGRAPHY_4,
				'selector' => '{{WRAPPER}} a.btn',
			]
		);

		$this->start_controls_tabs( 'tabs_button_style' );

		$this->start_controls_tab(
			'tab_button_normal',
			[
				'label' => __( 'Normal', 'struct-plugin' ),
			]
		);

		$this->add_control(
			'button_text_color',
			[
				'label'     => __( 'Text Color', 'struct-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} a.btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'background_color',
			[
				'label'     => __( 'Background Color', 'struct-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'scheme'    => [
					'type'  => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_4,
				],
				'selectors' => [
					'{{WRAPPER}} a.btn' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			[
				'label' => __( 'Hover', 'struct-plugin' ),
			]
		);

		$this->add_control(
			'hover_color',
			[
				'label'     => __( 'Text Color', 'struct-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} a.btn:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_background_hover_color',
			[
				'label'     => __( 'Background Color', 'struct-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} a.btn:hover' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_border_color',
			[
				'label'     => __( 'Border Color', 'struct-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} a.btn:hover' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'      => 'border',
				'selector'  => '{{WRAPPER}} a.btn',
				'separator' => 'before',
			]
		);

		$this->add_control(
			'border_radius',
			[
				'label'      => __( 'Border Radius', 'struct-plugin' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} a.btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'button_box_shadow',
				'selector' => '{{WRAPPER}} a.btn',
			]
		);

		$this->add_responsive_control(
			'text_padding',
			[
				'label'      => __( 'Padding', 'struct-plugin' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors'  => [
					'{{WRAPPER}} a.btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator'  => 'before',
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings();

		$post_type  = $settings['post_types'];
		$post_id_bc = isset( $settings['selected_post'] ) ? $settings['selected_post'] : false;
		$post_id    = $settings[ 'selected_post_' . $post_type ] ? $settings[ 'selected_post_' . $post_type ] : $post_id_bc;

		if ( empty( $post_id ) ) {
			return;
		}

		$q = new \WP_Query( array(
			'post_type' => get_post_type( $post_id ),
			'p'         => $post_id,
		) );

		if ( $q->have_posts() ) {
			while ( $q->have_posts() ) : $q->the_post();
				$post_ext = '';

				if ( in_array( get_post_type(), array( 'post', 'struct_diy' ), true ) ) {
					$post_ext = '-' . get_post_type();
				}

				$template_path = 'template-parts/elementor/listing-item' . $post_ext . '.php';

				include locate_template( $template_path, false, false );
			endwhile;

			wp_reset_postdata();
		}

	}

}


