<?php
if ( ! class_exists( 'CI_Widget_Callout' ) ):
	class CI_Widget_Callout extends WP_Widget {

		protected $defaults = array(
			'title'       => '',
			'text'        => '',
			'button_text' => '',
			'button_url'  => '',
			'post_type'   => '',
		);

		function __construct() {
			$widget_ops  = array( 'description' => esc_html__( 'Callout widget with custom call to action button.', 'struct' ) );
			$control_ops = array();
			parent::__construct( 'ci-callout', $name = esc_html__( 'Theme - Callout', 'struct' ), $widget_ops, $control_ops );
		}

		function widget( $args, $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$id            = isset( $args['id'] ) ? $args['id'] : '';
			$before_widget = $args['before_widget'];
			$after_widget  = $args['after_widget'];

			$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

			$text        = $instance['text'];
			$button_text = $instance['button_text'];
			$button_url  = $instance['button_url'];
			$post_type   = $instance['post_type'];

			echo $before_widget;

			if ( $title ) {
				echo $args['before_title'] . $title . $args['after_title'];
			}

			if ( $text ) {
				echo wpautop( $text );
			}

			if ( ! empty( $button_text ) && ! empty( $button_url ) ) {
				?><a href="<?php echo esc_url( $button_url ); ?>" class="btn btn-sm"><?php echo wp_kses( $button_text, struct_get_allowed_tags() ); ?></a><?php
			}

			if ( ! empty( $post_type ) ) {
				$dd_id = 'select-' . $this->id;
				?>
				<div class="ci-select">
				<label class="sr-only" for="<?php echo esc_attr( $dd_id ); ?>"><?php esc_html_e( 'Select a post to visit.', 'struct' ); ?></label>
				<?php
					$dd = struct_dropdown_posts( array(
						'id'                   => $dd_id,
						'class'                => 'ci-post-select',
						'post_type'            => $post_type,
						'show_option_none'     => strip_tags( __( 'Select a post', 'struct' ) ),
						'select_even_if_empty' => true,
						'echo'                 => false,
					) );

					$dd = preg_replace_callback( '/(<option.*?value=)([\'""])(.*?)\2/', array( $this, 'convert_id_to_url' ), $dd );
					echo $dd;
				?></div><?php
			}

			echo $after_widget;

		} // widget

		function update( $new_instance, $old_instance ) {
			$instance = $old_instance;

			$instance['title']       = sanitize_text_field( $new_instance['title'] );
			$instance['text']        = wp_kses( $new_instance['text'], struct_get_allowed_tags() );
			$instance['button_text'] = wp_kses( $new_instance['button_text'], struct_get_allowed_tags() );
			$instance['button_url']  = esc_url_raw( $new_instance['button_url'] );
			$instance['post_type']   = in_array( $new_instance['post_type'], $this->get_available_post_types( 'names' ), true ) ? $new_instance['post_type'] : $this->defaults['post_type'];

			return $instance;
		}

		function form( $instance ) {

			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$title       = $instance['title'];
			$text        = $instance['text'];
			$button_text = $instance['button_text'];
			$button_url  = $instance['button_url'];
			$post_type   = $instance['post_type'];

			?>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'struct' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" class="widefat" /></p>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'text' ) ); ?>"><?php esc_html_e( 'Text:', 'struct' ); ?></label><textarea id="<?php echo esc_attr( $this->get_field_id( 'text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'text' ) ); ?>" class="widefat"><?php echo esc_textarea( $text ); ?></textarea></p>

			<p><label for="<?php echo esc_attr( $this->get_field_id( 'button_text' ) ); ?>"><?php esc_html_e( 'Button Text:', 'struct' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'button_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'button_text' ) ); ?>" type="text" value="<?php echo esc_attr( $button_text ); ?>" class="widefat" /></p>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'button_url' ) ); ?>"><?php esc_html_e( 'Button URL:', 'struct' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'button_url' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'button_url' ) ); ?>" type="text" value="<?php echo esc_attr( $button_url ); ?>" class="widefat" /></p>
			<?php

			$cpts_available = $this->get_available_post_types();
			?>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'post_type' ) ); ?>"><?php esc_html_e( 'Post type (optional):', 'struct' ); ?>
					<select id="<?php echo esc_attr( $this->get_field_id( 'post_type' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'post_type' ) ); ?>" class="widefat">
						<option value="" <?php selected( '', $post_type ); ?>></option>
						<?php foreach ( $cpts_available as $key => $pt ) {
							?><option value="<?php echo esc_attr( $key ); ?>" <?php selected( $key, $post_type ); ?>><?php echo esc_html( $pt->labels->name ); ?></option><?php
						} ?>
					</select>
				</label>
			</p>
			<?php
		} // form

		protected function get_available_post_types( $return = 'objects' ) {
			$return = in_array( $return, array( 'objects', 'names' ), true ) ? $return : 'objects';

			$post_types = get_post_types( array(
				'public' => true,
			), $return );

			unset( $post_types['attachment'] );
			unset( $post_types['struct_faq'] );

			return $post_types;
		}

		protected function convert_id_to_url( $matches ) {
			$value = '';
			if ( ! empty( $matches[3] ) ) {
				$value = get_permalink( intval( $matches[3] ) );
			}

			return $matches[1] . $matches[2] . esc_url( $value ) . $matches[2];
		}

	} // class

	register_widget( 'CI_Widget_Callout' );

endif;
