<?php
if ( ! class_exists( 'CI_Widget_Opening_Hours' ) ):
	class CI_Widget_Opening_Hours extends WP_Widget {

		protected $defaults = array(
			'title' => '',
			'text'  => '',
			'rows'  => array(),
		);

		function __construct() {
			$widget_ops  = array( 'description' => esc_html__( 'Opening hours table.', 'struct' ) );
			$control_ops = array();
			parent::__construct( 'ci-opening-hours', $name = esc_html__( 'Theme - Opening Hours', 'struct' ), $widget_ops, $control_ops );
		}

		function widget( $args, $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$id            = isset( $args['id'] ) ? $args['id'] : '';
			$before_widget = $args['before_widget'];
			$after_widget  = $args['after_widget'];

			$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

			$text = $instance['text'];
			$rows = $instance['rows'];

			echo $before_widget;

			if ( $title ) {
				echo $args['before_title'] . $title . $args['after_title'];
			}

			if ( $text ) {
				echo wpautop( $text );
			}

			if ( ! empty( $rows ) ) {
				?><table class="table table-opening-hours"><tbody><?php
					foreach ( $rows as $row ) {
						?>
						<tr>
							<th><?php echo esc_html( $row['day'] ); ?></th>
							<td><?php echo esc_html( $row['time'] ); ?></td>
						</tr>
						<?php
					}
				?></tbody></table><?php
			}

			echo $after_widget;

		} // widget

		function update( $new_instance, $old_instance ) {
			$instance = $old_instance;

			$instance['title'] = sanitize_text_field( $new_instance['title'] );
			$instance['text']  = wp_kses( $new_instance['text'], struct_get_allowed_tags() );
			$instance['rows']  = $this->sanitize_instance_rows( $new_instance );

			return $instance;
		}

		function form( $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$title = $instance['title'];
			$text  = $instance['text'];
			$rows  = $instance['rows'];

			$row_day_name  = $this->get_field_name( 'row_day' ) . '[]';
			$row_time_name = $this->get_field_name( 'row_time' ) . '[]';
			?>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'struct' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" class="widefat" /></p>

			<p><label for="<?php echo esc_attr( $this->get_field_id( 'text' ) ); ?>"><?php esc_html_e( 'Text:', 'struct' ); ?></label><textarea id="<?php echo esc_attr( $this->get_field_id( 'text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'text' ) ); ?>" class="widefat"><?php echo esc_textarea( $text ); ?></textarea></p>

			<p><?php esc_html_e( 'Add as many items as you want by pressing the "Add Item" button. Remove any item by selecting "Remove me".', 'struct' ); ?></p>
			<fieldset class="ci-repeating-fields">
				<div class="inner">
					<?php
						if ( ! empty( $rows ) ) {
							$count = count( $rows );
							for ( $i = 0; $i < $count; $i ++ ) {
								?>
								<div class="post-field">
									<label class="post-field-item"><?php esc_html_e( 'Day:', 'struct' ); ?>
										<input type="text" name="<?php echo esc_attr( $row_day_name ); ?>" value="<?php echo esc_attr( $rows[$i]['day'] ); ?>" class="widefat" />
									</label>

									<label class="post-field-item"><?php esc_html_e( 'Time:', 'struct' ); ?>
										<input type="text" name="<?php echo esc_attr( $row_time_name ); ?>" value="<?php echo esc_attr( $rows[$i]['time'] ); ?>" class="widefat" />
									</label>

									<p class="ci-repeating-remove-action"><a href="#" class="button ci-repeating-remove-field"><i class="dashicons dashicons-dismiss"></i><?php esc_html_e( 'Remove me', 'struct' ); ?></a></p>
								</div>
								<?php
							}
						}
					?>
					<?php
					//
					// Add an empty and hidden set for jQuery
					//
					?>
					<div class="post-field field-prototype" style="display: none;">
						<label class="post-field-item"><?php esc_html_e( 'Day:', 'struct' ); ?>
							<input type="text" name="<?php echo esc_attr( $row_day_name ); ?>" value="" class="widefat" />
						</label>

						<label class="post-field-item"><?php esc_html_e( 'Time:', 'struct' ); ?>
							<input type="text" name="<?php echo esc_attr( $row_time_name ); ?>" value="" class="widefat" />
						</label>

						<p class="ci-repeating-remove-action"><a href="#" class="button ci-repeating-remove-field"><i class="dashicons dashicons-dismiss"></i><?php esc_html_e( 'Remove me', 'struct' ); ?></a></p>
					</div>
				</div>
				<a href="#" class="ci-repeating-add-field button"><i class="dashicons dashicons-plus-alt"></i><?php esc_html_e( 'Add Item', 'struct' ); ?></a>
			</fieldset>
			<?php
		} // form

		protected function sanitize_instance_rows( $instance ) {
			if ( empty( $instance ) || ! is_array( $instance ) ) {
				return array();
			}

			$days  = $instance['row_day'];
			$times = $instance['row_time'];

			$count = max(
				count( $days ),
				count( $times )
			);

			$new_fields = array();

			$records_count = 0;

			for ( $i = 0; $i < $count; $i++ ) {
				if ( empty( $days[ $i ] ) && empty( $times[ $i ] ) ) {
					continue;
				}

				$new_fields[ $records_count ]['day']  = sanitize_text_field( $days[ $i ] );
				$new_fields[ $records_count ]['time'] = sanitize_text_field( $times[ $i ] );

				$records_count++;
			}
			return $new_fields;
		}

	} // class

	register_widget( 'CI_Widget_Opening_Hours' );

endif;
