<?php
if ( ! class_exists( 'CI_Widget_Slider' ) ):
	class CI_Widget_Slider extends WP_Widget {

		protected $defaults = array(
			'slideshow'       => 1,
			'slideshow_speed' => 3000,
			'slides'          => array(),
			'text_color'      => '',
		);

		function __construct() {
			$widget_ops  = array( 'description' => esc_html__( 'Homepage widget. Image and text slideshow.', 'struct' ) );
			$control_ops = array( 'width' => 400 );
			parent::__construct( 'ci-slideshow', $name = esc_html__( 'Theme - Slider', 'struct' ), $widget_ops, $control_ops );
		}

		function widget( $args, $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$before_widget = $args['before_widget'];
			$after_widget  = $args['after_widget'];

			$slideshow       = $instance['slideshow'] == 1 ? 1 : 0;
			$slideshow_speed = $instance['slideshow_speed'];
			$slides          = $instance['slides'];

			$text_color = $instance['text_color'];
			$text_style = ! empty( $text_color ) ? sprintf( 'color: %s;', $text_color ) : '';

			echo $before_widget;
			?>
			<div class="widget-wrap" style="<?php echo esc_attr( $text_style ); ?>">
				<div class="main-slider ci-slider loading"
					data-slideshow="<?php echo esc_attr( $slideshow ); ?>"
					data-slideshowspeed="<?php echo esc_attr( $slideshow_speed ); ?>"
					data-animation="fade"
					data-animationspeed="600">

					<ul class="slides">
						<?php foreach ( $slides as $slide ): ?>
							<?php
								$bg_image_url     = struct_get_image_src( $slide['bg_image_id'], 'struct_slide' );
								$background_style = ! empty( $bg_image_url ) ? sprintf( 'background-image: url(%s);', esc_url( $bg_image_url ) ) : '';
							?>
							<?php if ( ! empty( $slide['video_url'] ) ): ?>
								<li style="<?php echo esc_attr( $background_style ); ?>">
									<div class="slide-video-wrap">
										<?php echo wp_oembed_get( $slide['video_url'] ); ?>
									</div>
								</li>
							<?php else: ?>
								<?php ob_start(); ?>
								<?php $image_url = struct_get_image_src( $slide['image_id'], 'full' ); ?>
								<?php if ( ! empty( $image_url ) ): ?>
									<?php $img_info = wp_prepare_attachment_for_js( $slide['image_id'] ); ?>
									<div class="slide-content-img">
										<img src="<?php echo esc_url( $image_url ); ?>" alt="<?php echo esc_attr( $img_info['alt'] ); ?>">
									</div>
								<?php endif; ?>
								<?php $image_markup = ob_get_clean(); ?>

								<li style="<?php echo esc_attr( $background_style ); ?>">
									<?php
										$align_class   = ! empty( $slide['align'] ) ? 'slide-content-' . $slide['align'] : '';
										$noimage_class = $slide['align'] === 'center' && empty( $image_url ) ? ' slide-center-no-image' : '';
									?>
									<div class="slide-content-super <?php echo esc_attr( $align_class  . $noimage_class ); ?>">
										<div class="container">
											<div class="row">
												<div class="col-xs-12">
													<div class="slide-content-wrap">
														<?php if ( $slide['align'] == 'right' ) {
															echo $image_markup;
														} ?>
														<div class="slide-content-text">
															<?php if ( ! empty( $slide['title'] ) ): ?>
																<p class="hero-title"><?php echo esc_html( $slide['title'] ); ?></p>
															<?php endif; ?>

															<?php if ( ! empty( $slide['subtitle'] ) ): ?>
																<div class="hero-content-text"><?php echo wpautop( wp_kses( $slide['subtitle'], struct_get_allowed_tags() ) ); ?></div>
															<?php endif; ?>

															<?php if ( ! empty( $slide['button_text'] ) && ! empty( $slide['button_url'] ) ): ?>
																<a href="<?php echo esc_url( $slide['button_url'] ); ?>" class="btn btn-white btn-transparent"><?php echo esc_html( $slide['button_text'] ); ?></a>
															<?php endif; ?>

															<?php if ( ! empty( $slide['button2_text'] ) && ! empty( $slide['button2_url'] ) ): ?>
																<a href="<?php echo esc_url( $slide['button2_url'] ); ?>" class="btn"><?php echo esc_html( $slide['button2_text'] ); ?></a>
															<?php endif; ?>
														</div>
														<?php if ( $slide['align'] != 'right' ) {
															echo $image_markup;
														} ?>
													</div>
												</div>
											</div>
										</div>
									</div>
								</li>
							<?php endif; ?>
						<?php endforeach; ?>
					</ul>
				</div>
			</div>
			<?php

			echo $after_widget;
		} // widget

		function update( $new_instance, $old_instance ) {
			$instance = $old_instance;

			$instance['slideshow']       = struct_sanitize_checkbox_ref( $new_instance['slideshow'] );
			$instance['slideshow_speed'] = absint( $new_instance['slideshow_speed'] );
			$instance['slides']          = $this->sanitize_instance_slides( $new_instance );

			$instance['text_color'] = struct_sanitize_hex_color( $new_instance['text_color'] );

			return $instance;
		}

		function form( $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$slideshow       = $instance['slideshow'];
			$slideshow_speed = $instance['slideshow_speed'];
			$slides          = $instance['slides'];

			$text_color = $instance['text_color'];

			$slide_image_name     = $this->get_field_name( 'slide_image' ) . '[]';
			$slide_bg_image_name  = $this->get_field_name( 'slide_bg_image' ) . '[]';
			$slide_title_name     = $this->get_field_name( 'slide_title' ) . '[]';
			$slide_video_url_name = $this->get_field_name( 'slide_video_url' ) . '[]';
			$slide_subtitle_name  = $this->get_field_name( 'slide_subtitle' ) . '[]';
			$slide_btn_text_name  = $this->get_field_name( 'slide_button_text' ) . '[]';
			$slide_btn_link_name  = $this->get_field_name( 'slide_button_url' ) . '[]';
			$slide_btn2_text_name = $this->get_field_name( 'slide_button2_text' ) . '[]';
			$slide_btn2_link_name = $this->get_field_name( 'slide_button2_url' ) . '[]';
			$slide_align_name     = $this->get_field_name( 'slide_align' ) . '[]';
			?>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'slideshow' ) ); ?>"><input type="checkbox" name="<?php echo esc_attr( $this->get_field_name( 'slideshow' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'slideshow' ) ); ?>" value="1" <?php checked( $slideshow, 1 ); ?> /><?php esc_html_e( 'Enable slideshow (auto-play).', 'struct' ); ?></label></p>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'slideshow_speed' ) ); ?>"><?php esc_html_e( 'Pause between slides (milliseconds):', 'struct' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'slideshow_speed' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'slideshow_speed' ) ); ?>" type="number" min="0" step="100" value="<?php echo esc_attr( $slideshow_speed ); ?>" class="widefat" /></p>

			<p><?php esc_html_e( 'Add as many items as you want by pressing the "Add Item" button. Remove any item by selecting "Remove me".', 'struct' ); ?></p>
			<p><?php echo wp_kses( sprintf( __( 'You may provide a video URL from a supported website, to show a video instead of an image. A list of supported websites can be <a href="%s" target="_blank">found here</a>.', 'struct' ), 'https://codex.wordpress.org/Embeds#Okay.2C_So_What_Sites_Can_I_Embed_From.3F' ), struct_get_allowed_tags( 'guide' ) ); ?></p>

			<fieldset class="ci-repeating-fields">
				<div class="inner">
					<?php
						if ( ! empty( $slides ) ) {
							$count = count( $slides );
							for ( $i = 0; $i < $count; $i ++ ) {
								?>
								<div class="post-field">
									<label class="post-field-item"><?php esc_html_e( 'Slide Background Image:', 'struct' ); ?>
										<div class="ci-upload-preview">
											<div class="upload-preview">
												<?php if ( ! empty( $slides[$i]['bg_image_id'] ) ): ?>
													<?php
														$image_url = struct_get_image_src( $slides[$i]['bg_image_id'], 'struct_featgal_small_thumb' );
														echo sprintf( '<img src="%s" /><a href="#" class="close media-modal-icon" title="%s"></a>',
															esc_url( $image_url ),
															esc_attr__( 'Remove image', 'struct' )
														);
													?>
												<?php endif; ?>
											</div>
											<input type="hidden" class="ci-uploaded-id" name="<?php echo esc_attr( $slide_bg_image_name ); ?>" value="<?php echo esc_attr( $slides[$i]['bg_image_id'] ); ?>" />
											<input type="button" class="button ci-media-button" value="<?php esc_attr_e( 'Select Image', 'struct' ); ?>" />
										</div>
									</label>

									<label class="post-field-item"><?php esc_html_e( 'Slide Image:', 'struct' ); ?>
										<div class="ci-upload-preview">
											<div class="upload-preview">
												<?php if ( ! empty( $slides[$i]['image_id'] ) ): ?>
													<?php
														$image_url = struct_get_image_src( $slides[$i]['image_id'], 'struct_featgal_small_thumb' );
														echo sprintf( '<img src="%s" /><a href="#" class="close media-modal-icon" title="%s"></a>',
															esc_url( $image_url ),
															esc_attr__( 'Remove image', 'struct' )
														);
													?>
												<?php endif; ?>
											</div>
											<input type="hidden" class="ci-uploaded-id" name="<?php echo esc_attr( $slide_image_name ); ?>" value="<?php echo esc_attr( $slides[$i]['image_id'] ); ?>" />
											<input type="button" class="button ci-media-button" value="<?php esc_attr_e( 'Select Image', 'struct' ); ?>" />
										</div>
									</label>

									<label class="post-field-item"><?php esc_html_e( 'Video URL:', 'struct' ); ?>
										<input type="text" name="<?php echo esc_attr( $slide_video_url_name ); ?>" value="<?php echo esc_attr( $slides[ $i ]['video_url'] ); ?>" class="widefat"/>
									</label>

									<label class="post-field-item"><?php esc_html_e( 'Title:', 'struct' ); ?>
										<input type="text" name="<?php echo esc_attr( $slide_title_name ); ?>" value="<?php echo esc_attr( $slides[$i]['title'] ); ?>" class="widefat" />
									</label>

									<label class="post-field-item"><?php esc_html_e( 'Subtitle:', 'struct' ); ?>
										<input type="text" name="<?php echo esc_attr( $slide_subtitle_name ); ?>" value="<?php echo esc_attr( $slides[$i]['subtitle'] ); ?>" class="widefat" />
									</label>

									<label class="post-field-item"><?php esc_html_e( 'Transparent Button text:', 'struct' ); ?>
										<input type="text" name="<?php echo esc_attr( $slide_btn_text_name ); ?>" value="<?php echo esc_attr( $slides[$i]['button_text'] ); ?>" class="widefat" />
									</label>

									<label class="post-field-item"><?php esc_html_e( 'Transparent Button URL:', 'struct' ); ?>
										<input type="text" name="<?php echo esc_attr( $slide_btn_link_name ); ?>" value="<?php echo esc_url( $slides[$i]['button_url'] ); ?>" class="widefat" />
									</label>

									<?php
										if ( ! isset( $slides[ $i ]['button2_text'] ) || ! isset( $slides[ $i ]['button2_url'] ) ) {
											$slides[ $i ]['button2_text'] = '';
											$slides[ $i ]['button2_url']  = '';
										}
									?>
									<label class="post-field-item"><?php esc_html_e( 'Solid Button text:', 'struct' ); ?>
										<input type="text" name="<?php echo esc_attr( $slide_btn2_text_name ); ?>" value="<?php echo esc_attr( $slides[$i]['button2_text'] ); ?>" class="widefat" />
									</label>

									<label class="post-field-item"><?php esc_html_e( 'Solid Button URL:', 'struct' ); ?>
										<input type="text" name="<?php echo esc_attr( $slide_btn2_link_name ); ?>" value="<?php echo esc_url( $slides[$i]['button2_url'] ); ?>" class="widefat" />
									</label>

									<label class="post-field-item"><?php esc_html_e( 'Text Align:', 'struct' ); ?>
										<select name="<?php echo esc_attr( $slide_align_name ); ?>" class="widefat">
											<option value="" <?php selected( '', $slides[ $i ]['align'] ); ?>><?php echo strip_tags( _x( 'Left', 'text align', 'struct' ) ); ?></option>
											<option value="center" <?php selected( 'center', $slides[ $i ]['align'] ); ?>><?php echo strip_tags( _x( 'Center', 'text align', 'struct' ) ); ?></option>
											<option value="right" <?php selected( 'right', $slides[ $i ]['align'] ); ?>><?php echo strip_tags( _x( 'Right', 'text align', 'struct' ) ); ?></option>
										</select>
									</label>
									<p class="ci-repeating-remove-action"><a href="#" class="button ci-repeating-remove-field"><i class="dashicons dashicons-dismiss"></i><?php esc_html_e( 'Remove me', 'struct' ); ?></a></p>
								</div>
								<?php
							}
						}
					?>
					<?php
					//
					// Add an empty and hidden set for jQuery
					//
					?>
					<div class="post-field field-prototype" style="display: none;">
						<label class="post-field-item"><?php esc_html_e( 'Slide Background Image:', 'struct' ); ?>
							<div class="ci-upload-preview">
								<div class="upload-preview"></div>
								<input type="hidden" class="ci-uploaded-id" name="<?php echo esc_attr( $slide_bg_image_name ); ?>" value="" />
								<input type="button" class="button ci-media-button" value="<?php esc_attr_e( 'Select Image', 'struct' ); ?>" />
							</div>
						</label>

						<label class="post-field-item"><?php esc_html_e( 'Slide Image:', 'struct' ); ?>
							<div class="ci-upload-preview">
								<div class="upload-preview"></div>
								<input type="hidden" class="ci-uploaded-id" name="<?php echo esc_attr( $slide_image_name ); ?>" value="" />
								<input type="button" class="button ci-media-button" value="<?php esc_attr_e( 'Select Image', 'struct' ); ?>" />
							</div>
						</label>

						<label class="post-field-item"><?php esc_html_e( 'Video URL:', 'struct' ); ?>
							<input type="text" name="<?php echo esc_attr( $slide_video_url_name ); ?>" value="" class="widefat"/>
						</label>

						<label class="post-field-item"><?php esc_html_e( 'Title:', 'struct' ); ?>
							<input type="text" name="<?php echo esc_attr( $slide_title_name ); ?>" value="" class="widefat" />
						</label>

						<label class="post-field-item"><?php esc_html_e( 'Subtitle:', 'struct' ); ?>
							<input type="text" name="<?php echo esc_attr( $slide_subtitle_name ); ?>" value="" class="widefat" />
						</label>

						<label class="post-field-item"><?php esc_html_e( 'Transparent Button text:', 'struct' ); ?>
							<input type="text" name="<?php echo esc_attr( $slide_btn_text_name ); ?>" value="" class="widefat" />
						</label>

						<label class="post-field-item"><?php esc_html_e( 'Transparent Button URL:', 'struct' ); ?>
							<input type="text" name="<?php echo esc_attr( $slide_btn_link_name ); ?>" value="" class="widefat" />
						</label>

						<label class="post-field-item"><?php esc_html_e( 'Solid Button text:', 'struct' ); ?>
							<input type="text" name="<?php echo esc_attr( $slide_btn2_text_name ); ?>" value="" class="widefat" />
						</label>

						<label class="post-field-item"><?php esc_html_e( 'Solid Button URL:', 'struct' ); ?>
							<input type="text" name="<?php echo esc_attr( $slide_btn2_link_name ); ?>" value="" class="widefat" />
						</label>

						<label class="post-field-item"><?php esc_html_e( 'Text Align:', 'struct' ); ?>
							<select name="<?php echo esc_attr( $slide_align_name ); ?>" class="widefat">
								<option value=""><?php echo strip_tags( _x( 'Left', 'text align', 'struct' ) ); ?></option>
								<option value="center"><?php echo strip_tags( _x( 'Center', 'text align', 'struct' ) ); ?></option>
								<option value="right"><?php echo strip_tags( _x( 'Right', 'text align', 'struct' ) ); ?></option>
							</select>
						</label>
						<p class="ci-repeating-remove-action"><a href="#" class="button ci-repeating-remove-field"><i class="dashicons dashicons-dismiss"></i><?php esc_html_e( 'Remove me', 'struct' ); ?></a></p>
					</div>
				</div>
				<a href="#" class="ci-repeating-add-field button"><i class="dashicons dashicons-plus-alt"></i><?php esc_html_e( 'Add Item', 'struct' ); ?></a>
			</fieldset>

			<fieldset class="ci-collapsible">
				<legend><?php esc_html_e( 'Customize', 'struct' ); ?> <i class="dashicons dashicons-arrow-down"></i></legend>
				<div class="elements">
					<p><label for="<?php echo esc_attr( $this->get_field_id( 'text_color' ) ); ?>"><?php esc_html_e( 'Text Color:', 'struct' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'text_color' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'text_color' ) ); ?>" type="text" value="<?php echo esc_attr( $text_color ); ?>" class="struct-color-picker widefat"/></p>
				</div>
			</fieldset>

			<?php
		} // form

		protected function sanitize_instance_slides( $instance ) {
			if ( empty( $instance ) || ! is_array( $instance ) ) {
				return array();
			}

			$bg_images  = $instance['slide_bg_image'];
			$images     = $instance['slide_image'];
			$video_urls = $instance['slide_video_url'];
			$titles     = $instance['slide_title'];
			$subtitles  = $instance['slide_subtitle'];
			$btn_texts  = $instance['slide_button_text'];
			$btn_urls   = $instance['slide_button_url'];
			$btn2_texts  = $instance['slide_button2_text'];
			$btn2_urls   = $instance['slide_button2_url'];
			$aligns     = $instance['slide_align'];

			$count = max(
				count( $bg_images ),
				count( $images ),
				count( $video_urls ),
				count( $titles ),
				count( $subtitles ),
				count( $btn_texts ),
				count( $btn_urls ),
				count( $btn2_texts ),
				count( $btn2_urls ),
				count( $aligns )
			);

			$new_fields = array();

			$records_count = 0;

			for ( $i = 0; $i < $count; $i++ ) {
				if ( empty( $bg_images[ $i ] )
				     && empty( $images[ $i ] )
				     && empty( $video_urls[ $i ] )
				     && empty( $titles[ $i ] )
				     && empty( $subtitles[ $i ] )
				     && empty( $btn_texts[ $i ] )
				     && empty( $btn_urls[ $i ] )
				     && empty( $btn2_texts[ $i ] )
				     && empty( $btn2_urls[ $i ] )
				) {
					continue;
				}

				$new_fields[ $records_count ]['bg_image_id']  = struct_sanitize_intval_or_empty( $bg_images[ $i ] );
				$new_fields[ $records_count ]['image_id']     = struct_sanitize_intval_or_empty( $images[ $i ] );
				$new_fields[ $records_count ]['video_url']    = esc_url_raw( $video_urls[ $i ] );
				$new_fields[ $records_count ]['title']        = sanitize_text_field( $titles[ $i ] );
				$new_fields[ $records_count ]['subtitle']     = wp_kses( $subtitles[ $i ], struct_get_allowed_tags() );
				$new_fields[ $records_count ]['button_text']  = sanitize_text_field( $btn_texts[ $i ] );
				$new_fields[ $records_count ]['button_url']   = esc_url_raw( $btn_urls[ $i ] );
				$new_fields[ $records_count ]['button2_text'] = sanitize_text_field( $btn2_texts[ $i ] );
				$new_fields[ $records_count ]['button2_url']  = esc_url_raw( $btn2_urls[ $i ] );
				$new_fields[ $records_count ]['align']        = in_array( $aligns[ $i ], array( '', 'center', 'right' ), true ) ? $aligns[ $i ] : '';

				$records_count++;
			}
			return $new_fields;
		}

	} // class

	register_widget( 'CI_Widget_Slider' );

endif;