<?php
if ( ! class_exists( 'CI_Widget_Video' ) ):
	class CI_Widget_Video extends WP_Widget {

		protected $defaults = array(
			'title'             => '',
			'subtitle'          => '',
			'video_url'         => '',
			'image_id'          => '',
			'text_color'        => '',
			'background_color'  => '',
			'background_image'  => '',
			'background_cover'  => 1,
			'background_repeat' => 'no-repeat',
			'extra_padding'     => '',
		);

		function __construct() {
			$widget_ops  = array( 'description' => esc_html__( 'Homepage widget. Display a video, optionally including it inside a lightbox.', 'struct' ) );
			$control_ops = array( 'width' => 400 );
			parent::__construct( 'ci-video', $name = esc_html__( 'Theme - Video', 'struct' ), $widget_ops, $control_ops );

			add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_custom_css' ) );
		}

		function widget( $args, $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$id            = isset( $args['id'] ) ? $args['id'] : '';
			$before_widget = $args['before_widget'];
			$after_widget  = $args['after_widget'];

			$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

			$subtitle  = $instance['subtitle'];
			$image_id  = $instance['image_id'];
			$video_url = $instance['video_url'];

			$image_url = struct_get_image_src( $image_id, 'struct_featured' );

			$background_color = $instance['background_color'];
			$background_image = $instance['background_image'];
			$extra_padding    = $instance['extra_padding'] == 1 ? 'wrap-extra-pad' : '';

			if ( ! empty( $background_color ) || ! empty( $background_image ) ) {
				preg_match( '/class=(["\']).*?widget.*?\1/', $before_widget, $match );
				if ( ! empty( $match ) ) {
					$attr_class    = preg_replace( '/\bwidget\b/', 'widget widget-padded', $match[0], 1 );
					$before_widget = str_replace( $match[0], $attr_class, $before_widget );
				}
			}

			echo $before_widget;

			?><div class="widget-wrap <?php echo esc_attr( $extra_padding ); ?>"><?php

			if ( in_array( $id, struct_get_fullwidth_sidebars() ) ) {
				?>
				<div class="container">
					<div class="row">
				<?php
			}


			?><div class="col-lg-10 offset-lg-1 col-xs-12"><?php

			if ( $title || $subtitle ) {
				?><div class="section-title-wrap"><?php
				if ( $title ) {
					echo $args['before_title'] . $title . $args['after_title'];
				}

				if ( $subtitle ) {
					?><p class="section-subtitle"><?php echo wp_kses( $subtitle, struct_allowed_subtitle_tags() ); ?></p><?php
				}
				?></div><?php
			}

			if ( ! empty( $video_url ) ) {
				?><div class="ci-hero-vid"><?php

				if ( empty( $image_url ) ) {
					echo wp_oembed_get( $video_url );
				} else {
					$attachment = wp_prepare_attachment_for_js( $image_id );
					?>
					<a href="<?php echo esc_url( $video_url ); ?>" class="ci-video-lightbox">
						<img src="<?php echo esc_url( $image_url ); ?>" alt="<?php echo esc_attr( $attachment['alt'] ); ?>">
					</a>
					<?php
				}

				?></div><?php
			}

			?></div><?php


			if ( in_array( $id, struct_get_fullwidth_sidebars() ) ) {
				?>
					</div>
				</div>
				<?php
			}

			?></div><?php

			echo $after_widget;

		} // widget

		function update( $new_instance, $old_instance ) {
			$instance = $old_instance;

			$instance['title']     = sanitize_text_field( $new_instance['title'] );
			$instance['subtitle']  = wp_kses( $new_instance['subtitle'], struct_allowed_subtitle_tags() );
			$instance['image_id']  = struct_sanitize_intval_or_empty( $new_instance['image_id'] );
			$instance['video_url'] = esc_url_raw( $new_instance['video_url'] );

			$instance['text_color']        = struct_sanitize_hex_color( $new_instance['text_color'] );
			$instance['background_color']  = struct_sanitize_hex_color( $new_instance['background_color'] );
			$instance['background_image']  = esc_url_raw( $new_instance['background_image'] );
			$instance['background_cover']  = struct_sanitize_checkbox_ref( $new_instance['background_cover'] );
			$instance['background_repeat'] = in_array( $new_instance['background_repeat'], array( 'repeat', 'no-repeat', 'repeat-x', 'repeat-y' ) ) ? $new_instance['background_repeat'] : $this->defaults['background_repeat'];
			$instance['extra_padding']     = struct_sanitize_checkbox_ref( $new_instance['extra_padding'] );

			return $instance;
		}

		function form( $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$title     = $instance['title'];
			$subtitle  = $instance['subtitle'];
			$image_id  = $instance['image_id'];
			$video_url = $instance['video_url'];

			$text_color        = $instance['text_color'];
			$background_color  = $instance['background_color'];
			$background_image  = $instance['background_image'];
			$background_cover  = $instance['background_cover'];
			$background_repeat = $instance['background_repeat'];
			$extra_padding     = $instance['extra_padding'];
			?>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'struct' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" class="widefat" /></p>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'subtitle' ) ); ?>"><?php esc_html_e( 'Subtitle:', 'struct' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'subtitle' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'subtitle' ) ); ?>" type="text" value="<?php echo esc_attr( $subtitle ); ?>" class="widefat" /></p>

			<p><label for="<?php echo esc_attr( $this->get_field_id( 'video_url' ) ); ?>"><?php esc_html_e( 'Video URL (only YouTube or Vimeo):', 'struct' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'video_url' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'video_url' ) ); ?>" type="text" value="<?php echo esc_attr( $video_url ); ?>" class="widefat" /></p>

			<p>
				<label class="post-field-item"><?php esc_html_e( 'Cover Image (optional):', 'struct' ); ?>
					<div class="ci-upload-preview">
						<div class="upload-preview">
							<?php if ( ! empty( $image_id ) ): ?>
								<?php
									$image_url = struct_get_image_src( $image_id, 'struct_featgal_small_thumb' );
									echo sprintf( '<img src="%s" /><a href="#" class="close media-modal-icon" title="%s"></a>',
										esc_url( $image_url ),
										esc_attr__( 'Remove image', 'struct' )
									);
								?>
							<?php endif; ?>
						</div>
						<input type="hidden" class="ci-uploaded-id" name="<?php echo esc_attr( $this->get_field_name( 'image_id' ) ); ?>" value="<?php echo esc_attr( $image_id ); ?>" />
						<input type="button" class="button ci-media-button" value="<?php esc_attr_e( 'Select Image', 'struct' ); ?>" />
					</div>
				</label>
			</p>

			<fieldset class="ci-collapsible">
				<legend><?php esc_html_e( 'Customize', 'struct' ); ?> <i class="dashicons dashicons-arrow-down"></i></legend>
				<div class="elements">
					<p><label for="<?php echo esc_attr( $this->get_field_id( 'text_color' ) ); ?>"><?php esc_html_e( 'Text Color:', 'struct' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'text_color' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'text_color' ) ); ?>" type="text" value="<?php echo esc_attr( $text_color ); ?>" class="struct-color-picker widefat"/></p>
					<p><label for="<?php echo esc_attr( $this->get_field_id( 'background_color' ) ); ?>"><?php esc_html_e( 'Background Color:', 'struct' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'background_color' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'background_color' ) ); ?>" type="text" value="<?php echo esc_attr( $background_color ); ?>" class="struct-color-picker widefat"/></p>

					<p class="ci-collapsible-media"><label for="<?php echo esc_attr( $this->get_field_id( 'background_image' ) ); ?>"><?php esc_html_e( 'Background Image:', 'struct' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'background_image' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'background_image' ) ); ?>" type="text" value="<?php echo esc_attr( $background_image ); ?>" class="ci-uploaded-url widefat"/><a href="#" class="button ci-media-button"><?php esc_html_e( 'Select', 'struct' ); ?></a></p>
					<p><label for="<?php echo esc_attr( $this->get_field_id( 'background_cover' ) ); ?>"><input type="checkbox" name="<?php echo esc_attr( $this->get_field_name( 'background_cover' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'background_cover' ) ); ?>" value="1" <?php checked( $background_cover, 1 ); ?> /><?php esc_html_e( 'Background image covers available area (repeat option is ignored).', 'struct' ); ?></label></p>
					<p>
						<label for="<?php echo esc_attr( $this->get_field_id( 'background_repeat' ) ); ?>"><?php esc_html_e( 'Background Repeat:', 'struct' ); ?></label>
						<select id="<?php echo esc_attr( $this->get_field_id( 'background_repeat' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'background_repeat' ) ); ?>">
							<option value="repeat" <?php selected( 'repeat', $background_repeat ); ?>><?php esc_html_e( 'Repeat', 'struct' ); ?></option>
							<option value="repeat-x" <?php selected( 'repeat-x', $background_repeat ); ?>><?php esc_html_e( 'Repeat Horizontally', 'struct' ); ?></option>
							<option value="repeat-y" <?php selected( 'repeat-y', $background_repeat ); ?>><?php esc_html_e( 'Repeat Vertically', 'struct' ); ?></option>
							<option value="no-repeat" <?php selected( 'no-repeat', $background_repeat ); ?>><?php esc_html_e( 'No Repeat', 'struct' ); ?></option>
						</select>
					</p>

					<p><label for="<?php echo esc_attr( $this->get_field_id( 'extra_padding' ) ); ?>"><input type="checkbox" name="<?php echo esc_attr( $this->get_field_name( 'extra_padding' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'extra_padding' ) ); ?>" value="1" <?php checked( $extra_padding, 1 ); ?> /><?php esc_html_e( 'Apply extra padding.', 'struct' ); ?></label></p>
				</div>
			</fieldset>
			<?php
		} // form

		function enqueue_custom_css() {
			$settings = $this->get_settings();

			if ( empty( $settings ) ) {
				return;
			}

			foreach ( $settings as $instance_id => $instance ) {
				$id = $this->id_base . '-' . $instance_id;

				if ( ! is_active_widget( false, $id, $this->id_base ) ) {
					continue;
				}

				$instance = wp_parse_args( (array) $instance, $this->defaults );

				$sidebar_id      = false; // Holds the sidebar id that the widget is assigned to.
				$sidebar_widgets = wp_get_sidebars_widgets();
				if ( ! empty( $sidebar_widgets ) ) {
					foreach ( $sidebar_widgets as $sidebar => $widgets ) {
						// We need to check $widgets for emptiness due to https://core.trac.wordpress.org/ticket/14876
						if ( ! empty( $widgets ) && array_search( $id, $widgets ) !== false ) {
							$sidebar_id = $sidebar;
						}
					}
				}

				$text_color        = $instance['text_color'];
				$background_color  = $instance['background_color'];
				$background_image  = $instance['background_image'];
				$background_cover  = $instance['background_cover'];
				$background_repeat = $instance['background_repeat'];

				$css         = '';
				$padding_css = '';

				if ( ! empty( $text_color ) ) {
					$css .= 'color: ' . $text_color . '; ';
				}
				if ( ! empty( $background_color ) ) {
					$css .= 'background-color: ' . $background_color . '; ';
				}
				if ( ! empty( $background_image ) ) {
					$css .= 'background-image: url(' . esc_url( $background_image ) . '); ';
					if ( $background_cover ) {
						$css .= 'background-size: cover; ';
					} else {
						$css .= 'background-size: auto; ';
						$css .= 'background-repeat: ' . $background_repeat . '; ';
					}
				}

				if ( ! empty( $css ) || ! empty( $padding_css ) ) {
					$css = '#' . $id . ' .widget-wrap { ' . $css . $padding_css . ' } ' . PHP_EOL;
					wp_add_inline_style( 'struct-style', $css );
				}

			}

		}

	} // class

	register_widget( 'CI_Widget_Video' );

endif;
