/**
 * Base Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Base Theme Customizer preview reload changes asynchronously.
 *
 * https://developer.wordpress.org/themes/customize-api/tools-for-improved-user-experience/#using-postmessage-for-improved-setting-previewing
 */

(function ($) {
	function createStyleSheet(settingName, styles) {
		var $styleElement;

		style = '<style class="' + settingName + '">';
		style += styles.reduce(function (rules, style) {
			rules += style.selectors + '{' + style.property + ':' + style.value + ';} ';
			return rules;
		}, '');
		style += '</style>';

		$styleElement = $('.' + settingName);

		if ($styleElement.length) {
			$styleElement.replaceWith(style);
		} else {
			$('head').append(style);
		}
	}

	//
	// Theme global colors
	//
	wp.customize('global_primary_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('global_primary_color', [
				{
					property: 'color',
					value: to,
					selectors: 'a,a:hover,.btn-transparent,.footer-copy a,.entry-title a:hover,.entry-meta-item::after,.entry-meta-item a:hover,.entry-content blockquote::before,.widget-title a:hover,.module-title a:hover,.item-title a:hover,.widget_meta ul li a:hover,.widget_pages ul li a:hover,.widget_categories ul li a:hover,.widget_archive ul li a:hover,.widget_recent_entries ul li a:hover,.navigation > li ul a:hover, .navigation > li ul .sfHover > a',
				},
				{
					property: 'background-color',
					value: to,
					selectors: '.ci-select select,.btn,input[type="button"],input[type="submit"],input[type="reset"],button,.comment-reply-link,.entry-content ul:not(.social-icons) li::before,.link-list-item a,.paging a:hover,.paging .current,.back-top,.faq-title,.sidebar .menu-item a,.social-icon:hover,.btn:hover,input[type="button"]:hover,input[type="submit"]:hover,input[type="reset"]:hover,button:hover,.comment-reply-link:hover,.link-list-item a:hover,.menu .current-menu-item > a,.sidebar .menu-item a:hover'
				},
				{
					property: 'border-color',
					value: to,
					selectors: '.btn-transparent,.item-pricing-featured,.item-icon,.social-icon, .btn-transparent:hover',
				},
				{
					property: 'border-bottom-color',
					value: to,
					selectors: '.navigation > li > a:hover,.navigation > li.sfHover > a,.navigation > li.sfHover > a:active,.navigation > li.current_page_item > a,.navigation > li.current-menu-item > a,.navigation > li.current-menu-ancestor > a,.navigation > li.current-menu-parent > a,.navigation > li.current > a,.entry-content a',
				}
			]);
		});
	});

	wp.customize('text_on_primary_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('text_on_primary_color', [
				{
					property: 'color',
					value: to,
					selectors: '.ci-select select,.ci-select::after,.btn,input[type="button"],input[type="submit"],input[type="reset"],button,.btn:hover,input[type="button"]:hover,input[type="submit"]:hover,input[type="reset"]:hover,button:hover,.footer .link-list-item a,.footer .menu-item a,.comment-reply-link,.paging a:hover,.paging .current,.faq-title,.sidebar .menu-item a,.sidebar .menu-item a:hover,.link-list-item a,.link-list-item a:hover,.social-icon:hover,.sidebar .social-icon:hover,.entry-content .social-icon:hover,.back-top,.back-top:hover,.menu .current-menu-item > a',
				}
			]);
		});
	});

	wp.customize('global_text_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('global_text_color', [
				{
					property: 'color',
					value: to,
					selectors: 'body,input,textarea,.btn-white,.btn-white.btn-transparent:hover,.widget .instagram-pics li a,.entry-title a,.entry-meta-item a,.module-testimonial-cite,.paging a,.paging > span,.paging li span,.navigation > li ul a,.widget_meta ul li a,.widget_pages ul li a,.widget_categories ul li a,.widget_archive ul li a,.widget_recent_entries ul li a,.social-icon,.sidebar .social-icon,.entry-content .social-icon,blockquote cite,.comment-notes,.form-allowed-tags',
				}
			]);
		});
	});

	wp.customize('global_link_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('global_link_color', [
				{
					property: 'color',
					value: to,
					selectors: '.entry-content a,.entry-content a:hover',
				}
			]);
		});
	});

	wp.customize('global_link_hover_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('global_link_hover_color', [
				{
					property: 'color',
					value: to,
					selectors: '.entry-content a:hover',
				}
			]);
		});
	});

	wp.customize('global_border_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('global_border_color', [
				{
					property: 'border-color',
					value: to,
					selectors: 'input,textarea,.widget select,.project-meta,.item-pricing,.navigation ul,.ci-map-wrap,input:focus,textarea:focus',
				},
				{
					property: 'border-top-color',
					value: to,
					selectors: '.entry-tags',
				},
				{
					property: 'border-bottom-color',
					value: to,
					selectors: '.table th,.table td,.project-meta th,.project-meta td',
				},
				{
					property: 'border-right-color',
					value: to,
					selectors: '.project-meta th,.project-meta td',
				},
				{
					property: 'background-color',
					value: to,
					selectors: '.paging a,.paging > span,.paging li span',
				}
			]);
		});
	});

	wp.customize('header_bg_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('header_bg_color', [
				{
					property: 'background-color',
					value: to,
					selectors: '.header',
				}
			]);
		});
	});

	wp.customize('header_nav_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('header_nav_color', [
				{
					property: 'color',
					value: to,
					selectors: '.navigation a, .logo a',
				}
			]);
		});
	});

	wp.customize('header_nav_color_hover', function (value) {
		value.bind(function (to) {
			createStyleSheet('header_nav_color_hover', [
				{
					property: 'color',
					value: to,
					selectors: '.navigation > li > a:hover,.navigation > li.sfHover > a,.navigation > li.sfHover > a:active,.navigation > li.current_page_item > a,.navigation > li.current-menu-item > a,.navigation > li.current-menu-ancestor > a,.navigation > li.current-menu-parent > a,.navigation > li.current > a,.navigation> li ul a:hover,.navigation > li ul .sfHover > a',
				}
			]);
		});
	});

	wp.customize('header_subnav_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('header_subnav_color', [
				{
					property: 'color',
					value: to,
					selectors: '.navigation > li ul a',
				}
			]);
		});
	});

	wp.customize('header_subnav_color_hover', function (value) {
		value.bind(function (to) {
			createStyleSheet('header_subnav_color_hover', [
				{
					property: 'color',
					value: to,
					selectors: '.navigation > li ul a:hover ',
				}
			]);
		});
	});

	wp.customize('header_subnav_bg_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('header_subnav_bg_color', [
				{
					property: 'background-color',
					value: to,
					selectors: '.navigation ul',
				},
				{
					property: 'border-bottom-color',
					value: to,
					selectors: '.navigation > li ul a',
				}
			]);
		});
	});

	//
	// Sidebar
	//
	wp.customize('sidebar_bg_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('sidebar_bg_color', [
				{
					property: 'background-color',
					value: to,
					selectors: '.sidebar',
				}
			]);
		});
	});

	wp.customize('sidebar_text_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('sidebar_text_color', [
				{
					property: 'color',
					value: to,
					selectors: '.sidebar',
				}
			]);
		});
	});

	wp.customize('sidebar_link_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('sidebar_link_color', [
				{
					property: 'color',
					value: to,
					selectors: '.sidebar a,.sidebar a:hover,.sidebar .widget_meta ul li a,.sidebar .widget_pages ul li a,.sidebar .widget_categories ul li a,.sidebar .widget_archive ul li a,.sidebar .widget_recent_entries ul li a',
				}
			]);
		});
	});

	wp.customize('sidebar_hover_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('sidebar_hover_color', [
				{
					property: 'color',
					value: to,
					selectors: '.sidebar a:hover,.sidebar .widget_meta ul li a:hover,.sidebar .widget_pages ul li a:hover,.sidebar .widget_categories ul li a:hover,.sidebar .widget_archive ul li a:hover,.sidebar .widget_recent_entries ul li a:hover',
				}
			]);
		});
	});

	wp.customize('sidebar_title_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('sidebar_title_color', [
				{
					property: 'color',
					value: to,
					selectors: '.sidebar .widget-title,.sidebar .widget-title a',
				},
				{
					property: 'background-color',
					value: to,
					selectors: '.sidebar .widget-title::after',
				}
			]);
		});
	});

	wp.customize('sidebar_border_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('sidebar_border_color', [
				{
					property: 'border-color',
					value: to,
					selectors: '.sidebar input,.sidebar textarea',
				}
			]);
		});
	});

	wp.customize('footer_bg_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('footer_bg_color', [
				{
					property: 'background-color',
					value: to,
					selectors: '.footer',
				}
			]);
		});
	});

	wp.customize('footer_text_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('footer_text_color', [
				{
					property: 'color',
					value: to,
					selectors: '.footer,.footer .widget_meta a,.footer .widget_pages a,.footer .widget_categories a,.footer .widget_archive a,.footer .widget_recent_entries a,.footer .widget_nav_menu a',
				}
			]);
		});
	});

	wp.customize('footer_link_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('footer_link_color', [
				{
					property: 'color',
					value: to,
					selectors: '.footer a:not(.btn),.footer .widget_meta a,.footer .widget_pages a,.footer .widget_categories a,.footer .widget_archive a,.footer .widget_recent_entries a,.footer .widget_nav_menu a',
				}
			]);
		});
	});

})(jQuery);
